<!-- Macros and functions for EU PPP reports, including appendix E format -->

<#--
	appendixEstudies prints information of a list of studies (ENDPOINT_STUDY_RECORDs, FLEXIBLE_RECORDs) following the structure 
	set in the Appendix E of EFSA's 2019 admin guidance for PPPs.

	Inputs:
		- subject: ENTITY or list of ENTITIES that studies belong to
		- docSubTypes: string or list of strings defining document's sub type e.g. "AnalyticalMethods"
		- context: list of hashmaps containing the conditions to be used to select which document(s) to output
			The hashmaps are definied in the ftls of the individual reports that use the appendixEstudies macro
			E.g. one example containing one condition for analytical methods for risk assessment is
				[{"path": "AdministrativeData.Endpoint", "val" : ["risk"], "qual" : "lk", "type" : "picklist"}] 
			Fur further description see 'filterStudyListbyContext' function
		- name: string with the name of the document to be displayed; if empty the name will be taken from the document subtype
		- section: string or list of strings containing the section(s) where the document needs to be cross-referenced in order to be output
			This is only applicable to the analytical methods section.
			E.g. section="6" or section=["7.1", "7.3"]
		- includeMetabolites: bool; if true, studies of the selected type in metabolite datasets will also be output
			This requires the global variable _metabolites to exist and have content.
			It is applicable for reports on the active substance (where metabolite studies should be also listed)
		- includeStudies: bool; if true studies are printed. In combination with includeWaivers it can control if to print studies, waivers, or both. 
		- includeWaivers: bool; if true waivers are printed. In combination with includeStudies it can control if to print studies, waivers, or both. 
		- includeRichTextFields: bool; if true print rich text fields of materials and methods, results, and overall remarks sections
		- includeImages: bool; if true print attached images
-->
<#macro appendixEstudies subject docSubTypes context="" name="" section="" includeMetabolites=true includeStudies=true includeWaivers=true includeRichTextFields=true includeImages=true includeAnnotations=false>
	<#compress>

		<#-- Convert docSubTypes to list, in case only one name provided -->
		<#if !docSubTypes?is_sequence>
			<#local docSubTypes=[docSubTypes]/>
		</#if>
		
		<#-- Create list of entities to loop for studies, based on subject -->
		<#if !subject?is_sequence>
			<#local entities=[subject]/>
		<#else>
			<#local entities=subject/>
		</#if>

		<#-- Get name of subject, if only one -->
		<#local subjectName><#if !subject?is_sequence>${getEntityName(subject)}</#if></#local>

		<#-- Get requirement name to display-->
		<#local name = getRequirementName(name, docSubTypes)>

		<#-- Add metabolites to the list of entities to loop for studies, if required -->
		<#if includeMetabolites && _metabolites?? && _metabolites?has_content>
			<#local entities = entities + _metabolites/>
		</#if>

		<#-- Get a hash of studies for results and data waivers for all entities-->
		<#local studyHash = createStudyHash(entities, docSubTypes, context, section)/>

		<#-- DATA WAIVING: if flag is true and there are data waivings, output waivers -->
		<#if includeWaivers && studyHash['dw']?has_content>

			<@com.emptyLine/>

			<para><emphasis role="HEAD-WoutNo">Data waiving</emphasis></para>

			<#list studyHash['dw'] as entityName, dataWaivingData>

				<#local dataWaivingStudyList=dataWaivingData['records']/>

				<#-- if the entity is not the subject, then it will be a metabolite, so print differently -->
				<#if (entityName!=subjectName)>
					<para><emphasis role="underline">----- Metabolite <emphasis role="bold">${entityName}</emphasis> -----</emphasis></para>
				</#if>

				<@dataWaiver dataWaivingStudyList name/>
			</#list>
		</#if>

		<#-- STUDY RESULTS: if flag is true, output studies -->
		<#if includeStudies>

			<#-- if there are no waivers or there are studies, print "Studies" title -->
			<#if !(studyHash['dw']?has_content) || studyHash['st']?has_content >
				<@com.emptyLine/>
				<para><emphasis role="HEAD-WoutNo">Studies</emphasis></para>
			</#if>

			<#-- if there are no studies, print text -->
			<#if !studyHash['st']?has_content>
				<#if !studyHash['dw']?has_content><@com.emptyLine/><para>No individual studies available for ${name}.</para><@com.emptyLine/></#if>

			<#else>

				<#-- print summary text for studies -->
				<para><@resultStudyHashSummaryText studyHash['st'] subjectName name/></para>
				<@com.emptyLine/>

				<#-- loop over entities -->
				<#local studyIndex=0/>
				<#list studyHash['st'] as entityName, resultData>
		
					<#local resultStudyList=resultData['records']/>
					<#local entity=resultData['entity']/>

					<#-- if the name of the entity is not the subject, then it's a metabolite -->
					<#if entityName!=subjectName>
						<para><emphasis role="underline">----- Metabolite <emphasis role="bold">${entityName}</emphasis> -----</emphasis></para>
					</#if>

					<#-- loop over studies -->
					<#list resultStudyList as study>
						
						<#local studyIndex=studyIndex+1/>

						<#-- create section and assign a label
							note: role="NotInToc" makes the section not appear in the main ToCs, based on the default stylesheet
						-->
						<sect4 xml:id="${study.documentKey.uuid!}" label="/${studyIndex}" role="NotInToc">

							<#local docUrl=iuclid.webUrl.documentView(study.documentKey) />

							<#-- set the title with hyperlink to the actual document in IUCLID -->
							<title  role="HEAD-5"><ulink url="${docUrl}"><@com.text study.name/></ulink></title>

							<#-- 1. AppendixE header-->
							<para><emphasis role="HEAD-WoutNo">1. Information on the study</emphasis></para>
							<@appendixEheader study entity/>

							<@com.emptyLine/>

							<#-- special case for analytical information (TO BE CHANGED AFTER FORMAT UPDATE) -->
							<#if study.documentSubType=="AnalyticalInformation" && keyPhyschem??>
								<@keyPhyschem.results_analyticalInformation study/>
							<#else>
							<#-- 2. AppendixE M&M and Results-->
							<para><emphasis role="HEAD-WoutNo">2. Full summary of the study according to OECD format</emphasis></para>

							<#-- 2a. Materials and methods
								There are different paths for materials and methods (or similar). The most standard
								is "MaterialsAndMethods" but in other documents there are different or additional ones.
							#-->

							<#-- background -->
							<#if study.hasElement("Background") && study.Background?has_content>
								<#if study.documentSubType=="EfficacyData">
									<para><emphasis role="bold">Basic information:</emphasis></para>
									<@keyEfficacy.basicinfo study/>
								
								<#elseif study.Background.BackgroundInformation?has_content>
									<para><emphasis role="bold">Background information:</emphasis></para>
									<para role="indent"><@com.text study.Background.BackgroundInformation/></para>
								</#if>

							</#if>

							<#-- general information -->
							<#if study.hasElement("GeneralInformation") && study.documentSubType=="EffectivenessAgainstTargetOrganisms" && keyBioPropMicro??>
								<@keyBioPropMicro.generalInfo_effectivenessTargetOrg study/>
							</#if>

							<#-- materials and methods -->
							<#if study.hasElement("MaterialsAndMethods")>
								<@appendixEmethods study includeRichTextFields/>
							</#if>

							<#--for intermediate effects-->
							<#if study.hasElement("EffectIdentification") && keyTox??>
								<@keyTox.intermediateEffectIdentification study/>
							</#if>

							<@com.emptyLine/>

							<#-- 2b. Results, including the overall remarks section-->
							<@appendixEresults study includeRichTextFields/>

							<@com.emptyLine/>

							<#if includeRichTextFields || includeImages>
								<@appendixEoverallRemarksAttachments study includeRichTextFields includeImages/>

								<@com.emptyLine/>
							</#if>

							<#-- 3. AppendixE Assessment and Conclusion-->
							<@appendixEconclusion study includeAnnotations />
							</#if>
						</sect4>
						<@com.emptyLine/>

					</#list>
				</#list>
			</#if>
			<@com.emptyLine/>
		</#if>
	</#compress>
</#macro>

<#-- appendixEheader prints some summary information of study records, following Appendix E structure.
	It  prints information from:
		- Administrateive data block
		- Materials and methods (guidelines, and glp)
		- Literature references (including NoSID)
		- Change log
	NOTE: Additional values from administrative data or LITERATURE could be eventually added (e.g study period, type of study, company owner, etc)

	Inputs:
		- study: DOCUMENT object
		- entity: ENTITY object
#-->
<#macro appendixEheader study entity>
	<#compress>

		<#--Get first study report literature reference, if references exist (if more than one reference, sort and take first study report)-->
		<#local reference=getStudyReference(study)/>

		<table border="1">
			<title> </title>
			<col width="30%" />
			<col width="70%" />
			<tbody valign="middle">
			<tr>
				<th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Data point</emphasis></th>
				<td>
					<#if study.documentSubType=="IntermediateEffects">
						intermediate effects: <@com.picklist study.AdministrativeData.StudyResultType/>
					<#elseif study.documentSubType=="AnalyticalInformation">
						spectra (UV/VIS, IR, NMR, MS), molar extinction at relevant wavelengths, optical purity
					<#else>
						<@com.picklist study.AdministrativeData.Endpoint/>
					</#if>
				</td>
			</tr>
			<tr>
				<th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Report type</emphasis></th>
				<td>
					${getReferenceElement(reference, "GeneralInfo.LiteratureType")}
				</td>
			</tr>
			<tr>
				<th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Report author</emphasis></th>
				<td>
					${getReferenceElement(reference, "GeneralInfo.Author")}
				</td>
			</tr>
			<tr>
				<th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Report year</emphasis></th>
				<td>
					${getReferenceElement(reference, "GeneralInfo.ReferenceYear")}
				</td>
			</tr>
			<tr>
				<th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Report title</emphasis></th>
				<td>
					${getReferenceElement(reference, "GeneralInfo.Name", true)}
				</td>
			</tr>
			<tr>
				<th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Report No</emphasis></th>
				<td>
					${getReferenceElement(reference, "GeneralInfo.ReportNo")}
				</td>
			</tr>
			<tr>
				<th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Document No</emphasis></th>
				<td>
					${getReferenceElement(reference, "GeneralInfo.CompanyOwnerStudyNo")}
				</td>
			</tr>
			<tr>
				<th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">NoS Id</emphasis></th>
				<td>
					${getNoSid(reference)}
				</td>
			</tr>
			<tr>
				<th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Guidelines followed in study</emphasis></th>
				<td>
					${getGuidelines(study)}
				</td>
			</tr>
			<tr>
				<th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Deviations from current test guideline</emphasis></th>
				<td>
					${getGuidelinesDeviation(study)}
				</td>
			</tr>
			<tr>
				<th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Previous evaluation</emphasis></th>
				<td>
					${getChangeLogStatus(study, entity)}
				</td>
			</tr>
			<tr>
				<th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">GLP/Officially recognised testing facilities</emphasis></th>
				<td>
					${getGLP(study)}
				</td>
			</tr>
			<tr>
				<th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Adequacy of study</emphasis></th>
				<td>
					<#if study.hasElement("AdministrativeData.PurposeFlag")>
						<@com.picklist study.AdministrativeData.PurposeFlag/>
					<#else>
						n.a.
					</#if>
				</td>
			</tr>
			<tr>
				<th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Acceptability/Reliability</emphasis></th>
				<td>
					<#if study.hasElement("AdministrativeData.Reliability")>
						<@com.picklist study.AdministrativeData.Reliability/><#if study.AdministrativeData.RationalReliability?has_content>: <@com.picklist study.AdministrativeData.RationalReliability/></#if>
					<#else>
						n.a.
					</#if>
				</td>
			</tr>
			</tbody>
		</table>
	</#compress>
</#macro>

<#-- appendixEconclusion prints information in the Applicant's summary and conclusion section

	Eventually, it could include the RMS opinion by including information from the annotation.
	
	Inputs:
		- study: DOCUMENT object
		- includeAnnotations: if true, include annotations by the RMS or Evaluator (TO BE IMPLEMENTED)
#-->
<#macro appendixEconclusion study includeAnnotations=false>
	<#compress>
		<para><emphasis role="HEAD-WoutNo">3. Assessment and conclusion </emphasis> </para>

		<#if includeAnnotations><para><emphasis role="bold">a) Assessment and conclusion by applicant:</emphasis></para></#if>

		<#-- Interpretation of results 
				NOTE: does not exist for all documents
		-->
		<#if study.hasElement("ApplicantSummaryAndConclusion.InterpretationOfResults") && study.ApplicantSummaryAndConclusion.InterpretationOfResults?has_content>
			<para>
				<emphasis role="bold">Interpretation of results: </emphasis><@com.picklist study.ApplicantSummaryAndConclusion.InterpretationOfResults/>
			</para>
			<#-- for intermediate effects -->
		<#elseif study.hasElement("ApplicantSSummaryAndConclusion.InterpretationOfResultsObservations") && study.ApplicantSSummaryAndConclusion.InterpretationOfResultsObservations?has_content>
			
			<para><emphasis role="bold">Interpretation of results:</emphasis></para>
			
			<#local int=study.ApplicantSSummaryAndConclusion.InterpretationOfResultsObservations/>
			
			<#if int.TypeOfResult?has_content>
				<para role="indent">Type of result: <@com.picklist int.TypeOfResult/></para>
			</#if>
			
			<#if int.EffectConcentrationChoice?has_content>
				<para role="indent">Effect concentration: <@com.picklist int.EffectConcentrationChoice/>
					<#if int.Concentration?has_content>
						= <@com.range int.Concentration/>
					</#if>
				</para>
			</#if>
			
			<#if int.Remarks?has_content>
				<para role="indent">Remarks: <@com.text int.Remarks/></para>
			</#if>

			<#if int.OverallResults?has_content>
				<para>
					<emphasis role="bold">Conclusion:</emphasis>
					<@com.text  int.OverallResults/>
				</para>
			</#if>
		</#if>

		<#-- Validity of criteria
				NOTE: does not exist for all documents
		-->
		<#if study.hasElement("ApplicantSummaryAndConclusion.ValidityCriteriaFulfilled") && study.ApplicantSummaryAndConclusion.ValidityCriteriaFulfilled?has_content>
			<para>
				<emphasis role="bold">Validity criteria fulfilled: </emphasis><@com.picklist study.ApplicantSummaryAndConclusion.ValidityCriteriaFulfilled/>
			</para>
		</#if>

		<#-- Executive summary 
				NOTE: different path options
		-->
		<#if study.hasElement("ApplicantSummaryAndConclusion.ExecutiveSummary") && study.ApplicantSummaryAndConclusion.ExecutiveSummary?has_content>
			<para><emphasis role="bold">Executive summary:</emphasis></para>
			<para><para style="background-color:#f7f7f7" role="indent"><@com.richText study.ApplicantSummaryAndConclusion.ExecutiveSummary/></para></para>
		
		<#elseif study.hasElement("ApplicantSSummaryAndConclusion.ExecutiveSummary.ExecutiveSummary") && study.ApplicantSSummaryAndConclusion.ExecutiveSummary.ExecutiveSummary?has_content>
			<#--for intermediate effects-->
			<para><emphasis role="bold">Executive summary:</emphasis></para>
			<para><para style="background-color:#f7f7f7" role="indent"><@com.richText study.ApplicantSSummaryAndConclusion.ExecutiveSummary.ExecutiveSummary/></para></para>
		</#if>

		<#-- Conclusion -->
		<#if study.hasElement("ApplicantSummaryAndConclusion.Conclusions") && study.ApplicantSummaryAndConclusion.Conclusions?has_content>
			<para>
				<emphasis role="bold">Conclusion:</emphasis>
				<para role="indent"><@com.text study.ApplicantSummaryAndConclusion.Conclusions/></para>
			</para>
		</#if>

		<#--  Annotations  -->
		<#if includeAnnotations>
			<para><emphasis role="bold">b) Assessment and conclusion by Evaluating Competent Authority:</emphasis></para>

			<@printAnnotationsforDoc study />
		</#if>
	</#compress>
</#macro>

<#-- appendixEmethods prints the materials and methods section of a study. 
	
	The part on test material is common to most templates and it's printed using this macro
	(including any fields contained within this path, which can very across documents).
	Specific m&m fields are printed using macros of the corresponding common_module for each 
	section (Tox, Ecotox, etc), depending on the document subtype.

	Printing the rich-text field on "Any other information on material and methods incl. tables" can be activated or deactivated.

	Inputs:
	- study: document object
	- includeRichTextFields: if true, it prints rich-text sections like "Any other results incl. tables"
-->
<#macro appendixEmethods study includeRichTextFields=true>

	<para><emphasis role="bold">a) Materials and methods</emphasis></para>

	<#-- Test material and additional test material -->
	<para><emphasis role="bold">Test material:</emphasis></para>
	<#local testMat=study.MaterialsAndMethods.TestMaterials/>
	<para role="indent"><@studyandsummaryCom.testMaterialInformation testMat.TestMaterialInformation/></para>

	<#if testMat.AdditionalTestMaterialInformation?has_content>
		<para role="indent">Additional test material(s):</para>
		<#list testMat.AdditionalTestMaterialInformation as addTestMat>
			<para role="indent2"><@studyandsummaryCom.testMaterialInformation addTestMat/></para>
		</#list>
	</#if>

	<#-- additional details on test materials -->
	<#if testMat.SpecificDetailsOnTestMaterialUsedForTheStudy?has_content ||
			testMat.SpecificDetailsOnTestMaterialUsedForTheStudyConfidential?has_content>
		<para role="indent">Specific details:</para>
		<#if testMat.SpecificDetailsOnTestMaterialUsedForTheStudy?has_content><para role="indent2"><@com.text study.MaterialsAndMethods.TestMaterials.SpecificDetailsOnTestMaterialUsedForTheStudy/></para></#if>
		<#if testMat.SpecificDetailsOnTestMaterialUsedForTheStudyConfidential?has_content><para role="indent2">[confidential] <@com.text study.MaterialsAndMethods.TestMaterials.SpecificDetailsOnTestMaterialUsedForTheStudyConfidential/></para></#if>
	</#if>

	<#-- print any children fields of the testMaterial, if they exist 
		NOTE: in FieldStudies this is probably by mistake under this path:DetailsOnSoilCharacteristics
	-->
	<@com.children path=testMat exclude=["TestMaterialInformation", "SpecificDetailsOnTestMaterialUsedForTheStudy",
											"SpecificDetailsOnTestMaterialUsedForTheStudyConfidential", "AdditionalTestMaterialInformation", 
											"DetailsOnSoilCharacteristics"] role1="indent" role2="indent2"/>

	<#-- specific methods: uses global variable _section -->
	<#if _section??>
		<#if _section=="Tox" && keyTox??>
			<@keyTox.toxMethodPPP study/>
		<#elseif _section=="Ecotox" && keyEcotox??>
			<@keyEcotox.ecotoxMethod study/>
		<#elseif _section=="Physchem" && keyPhyschem??>
			<@keyPhyschem.physchemMethod study/>
		<#elseif _section=="Residues" && keyRes??>
			<@keyRes.residuesMethod study/>
		<#elseif _section=="Anmeth" && keyAnMeth??>
			<@keyAnMeth.analyticalMethodsMethod study/>
		<#elseif _section=="Fate" && keyFate??>
			<@keyFate.fateMethod study/>
		<#elseif _section=="Efficacy" && keyEfficacy??>
			<@keyEfficacy.efficacyMethod study/>
		</#if>
	</#if>

	<#if study.documentSubType=="IntermediateEffects">
		<@keyTox.methods_intermediateEffects study/>
	</#if>

	<#if includeRichTextFields>
		
		<#--Any other information-->
		<#if study.MaterialsAndMethods.hasElement("AnyOtherInformationOnMaterialsAndMethodsInclTables") && study.MaterialsAndMethods.AnyOtherInformationOnMaterialsAndMethodsInclTables.OtherInformation?has_content>
			<para><emphasis role="bold">Other information:</emphasis></para>
			<para><para style="background-color:#f7f7f7" role="indent"><@com.richText study.MaterialsAndMethods.AnyOtherInformationOnMaterialsAndMethodsInclTables.OtherInformation/></para></para>
		</#if>

	</#if>

</#macro>

<#-- appendixEresults prints the results section of a study. 
	
	Specific result fields are printed using macros of the corresponding common_module for each 
	section (Tox, Ecotox, etc), depending on the document subtype.

	Printing the rich-text field on "Any other information on results incl. tables" can be activated or deactivated.

	Inputs:
	- study: document object
	- includeRichTextFields: if true, it prints rich-text sections like "Any other information on results incl. tables"
-->
<#macro appendixEresults study includeRichTextFields=true>
	<#compress>
		<para><emphasis role="bold">b) Results</emphasis></para>

		<#-- 1. Section-dependent specific result lists 
			NOTE: it seems in some cases ("TechnicalCharacteristics") this section has a different path
		-->

		<#--2. Physchem-->
		<#if study.documentSubType=='Melting'>
			<#if study.ResultsAndDiscussion.MeltingPoint?has_content>
				<para><emphasis role="bold">Melting point:</emphasis></para>
				<@keyPhyschem.meltingPointList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.MeltingPoint)/>
			</#if>
		<#elseif study.documentSubType=='BoilingPoint'>
			<#if study.ResultsAndDiscussion.BoilingPoint?has_content>
				<para><emphasis role="bold">Boiling point:</emphasis></para>
				<@keyPhyschem.boilingPointList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.BoilingPoint)/>
			</#if>
		<#elseif study.documentSubType=='Vapour'>
			<#if study.ResultsAndDiscussion.Vapourpr?has_content>
				<para><emphasis role="bold">Vapour pressure:</emphasis></para>
				<@keyPhyschem.vapourprList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.Vapourpr)/>
			</#if>
			<#if study.ResultsAndDiscussion.VapourPressureAt50CIfRelevantForClassificationOfGasUnderPressure?has_content>
				<para><emphasis role="bold">Vapour pressure at 50°C:</emphasis></para>
				<@keyPhyschem.vapourprAt50List studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.VapourPressureAt50CIfRelevantForClassificationOfGasUnderPressure)/>
			</#if>
			<#if study.ResultsAndDiscussion.Transition?has_content>
				<para><emphasis role="bold">Transition / decomposition:</emphasis></para>
				<@keyPhyschem.vapourTransitionList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.Transition)/>
			</#if>
		<#elseif study.documentSubType=="HenrysLawConstant">
			<#if study.ResultsAndDiscussion.HenrysLawConstantH?has_content>
				<para><emphasis role="bold">Henry's Law Constant H:</emphasis></para>
				<@keyPhyschem.henrysLawConstantHList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.HenrysLawConstantH)/>
			</#if>
		<#elseif study.documentSubType=="GeneralInformation">
			<#if study.ResultsAndDiscussion.SubstancePhysicalState?has_content>
				<para><emphasis role="bold">Physical state at 20°C and 1013 hPa:</emphasis></para>
				<para role="indent"><@com.picklist study.ResultsAndDiscussion.SubstancePhysicalState/></para>
			</#if>
			<#if study.ResultsAndDiscussion.SubstanceType?has_content>
				<para><emphasis role="bold">Substance type:</emphasis></para>
				<para role="indent"><@com.picklist study.ResultsAndDiscussion.SubstanceType/></para>
			</#if>
			<#if study.ResultsAndDiscussion.FormBlock?has_content>
				<para><emphasis role="bold">Form / colour/ odour:</emphasis></para>
				<@keyPhyschem.appearanceList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.FormBlock)/>
			</#if>
		<#elseif study.documentSubType=="WaterSolubility">
			<#if study.ResultsAndDiscussion.WaterSolubility?has_content>
				<para><emphasis role="bold">Water solubility:</emphasis></para>
				<@keyPhyschem.waterSolubilityList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.WaterSolubility)/>
			</#if>
			<#if study.ResultsAndDiscussion.SolubilityOfMetalIonsInAqueousMedia?has_content>
				<para><emphasis role="bold">Solubility of metal ions in aqueous media:</emphasis></para>
				<@keyPhyschem.solubilityMetalList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.SolubilityOfMetalIonsInAqueousMedia)/>
			</#if>
			<#if study.ResultsAndDiscussion.DetailsOnResults?has_content>
				<para><emphasis role="bold">Details on results:</emphasis></para>
				<para role="indent"><@com.text study.ResultsAndDiscussion.DetailsOnResults/></para>
			</#if>
		<#elseif study.documentSubType=="SolubilityOrganic">
			<#if study.ResultsAndDiscussion.SolubilityOrganic?has_content>
				<para><emphasis role="bold">Solubility in organic solvents / fat solubility:</emphasis></para>
				<@keyPhyschem.solubilityOrganicList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.SolubilityOrganic)/>
			</#if>
			<#if study.ResultsAndDiscussion.TestSubstanceTable?has_content>
				<para><emphasis role="bold">Test substance stable:</emphasis></para>
				<para role="indent"><@com.picklist study.ResultsAndDiscussion.TestSubstanceTable/></para>
			</#if>
			<#if study.ResultsAndDiscussion.DetailsOnResults?has_content>
				<para><emphasis role="bold">Details on results:</emphasis></para>
				<para role="indent"><@com.text study.ResultsAndDiscussion.DetailsOnResults/></para>
			</#if>
		<#elseif study.documentSubType=="Partition">
			<#if study.ResultsAndDiscussion.Partcoeff?has_content>
				<para><emphasis role="bold">Partition coefficient:</emphasis></para>
				<@keyPhyschem.partcoeffList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.Partcoeff)/>
			</#if>
			<#if study.ResultsAndDiscussion.DetailsOnResults?has_content>
				<para><emphasis role="bold">Details on results:</emphasis></para>
				<para role="indent"><@com.text study.ResultsAndDiscussion.DetailsOnResults/></para>
			</#if>
		<#elseif study.documentSubType=="DissociationConstant">
			<#if study.ResultsAndDiscussion.DissociatingProperties?has_content>
				<para><emphasis role="bold">Dissociating properties:</emphasis></para>
				<para role="indent"><@com.picklist study.ResultsAndDiscussion.DissociatingProperties/></para>
			</#if>
			<#if study.ResultsAndDiscussion.DissociationConstant?has_content>
				<para><emphasis role="bold">Dissociation constant:</emphasis></para>
				<@keyPhyschem.dissociationConstantList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.DissociationConstant)/>
			</#if>
		<#elseif study.documentSubType=="Flammability">
			<#if study.ResultsAndDiscussion.FlammableGasesLowerAndUpperExplosionLimit?has_content>
				<para><emphasis role="bold">Flammable gasses (lower and upper explosion limits):</emphasis></para>
				<@keyPhyschem.flammableGasesList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.FlammableGasesLowerAndUpperExplosionLimit)/>
			</#if>
			<#if study.ResultsAndDiscussion.Aerosols?has_content>
				<para><emphasis role="bold">Aerosols:</emphasis></para>
				<@keyPhyschem.aerosolsList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.Aerosols)/>
			</#if>
			<#if study.ResultsAndDiscussion.FlammableSolids?has_content>
				<para><emphasis role="bold">Flammable solids:</emphasis></para>
				<@keyPhyschem.flammableSolidsList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.FlammableSolids)/>
			</#if>
			<#if study.ResultsAndDiscussion.PyrophoricSolids?has_content>
				<para><emphasis role="bold">Pyrophoric solids:</emphasis></para>
				<@keyPhyschem.pyrophoricSolidsList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.PyrophoricSolids)/>
			</#if>
			<#if study.ResultsAndDiscussion.PyrophoricLiquids?has_content>
				<para><emphasis role="bold">Pyrophoric liquid:</emphasis></para>
				<@keyPhyschem.pyrophoricLiquidList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.PyrophoricLiquids)/>
			</#if>
			<#if study.ResultsAndDiscussion.SelfHeatingSubstancesMixtures?has_content>
				<para><emphasis role="bold">Self-heating substances/mixtures:</emphasis></para>
				<@keyPhyschem.selfHeatingSubstancesMixturesList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.SelfHeatingSubstancesMixtures)/>
			</#if>
			<#if study.ResultsAndDiscussion.SubstancesMixturesWhichInContactWithWaterEmitFlammableGases?has_content>
				<para><emphasis role="bold">Substances/ mixture which in contact with water emit flammable gases:</emphasis></para>
				<@keyPhyschem.substancesMixturesWithWaterEmitFlammableGasesList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.SubstancesMixturesWhichInContactWithWaterEmitFlammableGases)/>
			</#if>
		<#elseif study.documentSubType=="AutoFlammability">
			<#if study.ResultsAndDiscussion.AutoFlammability?has_content>
				<para><emphasis role="bold">Auto-ignition temperature (liquids / gases):</emphasis></para>
				<@keyPhyschem.autoFlammabilityList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.AutoFlammability)/>
			</#if>
			<#if study.ResultsAndDiscussion.RelativeSelfIgnitionTemperatureSolids?has_content>
				<para><emphasis role="bold">Relative self-ignition temperature (solids):</emphasis></para>
				<@keyPhyschem.relativeSelfIgnitionTemperatureSolidsList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.RelativeSelfIgnitionTemperatureSolids)/>
			</#if>
			<#if study.ResultsAndDiscussion.SelfIgnitionTemperatureOfDustAccumulation?has_content>
				<para><emphasis role="bold">Self-ignition temperature of dust accumulation:</emphasis></para>
				<@keyPhyschem.selfIgnitionTemperatureOfDustAccumulationList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.SelfIgnitionTemperatureOfDustAccumulation)/>
			</#if>
		<#elseif study.documentSubType=="FlashPoint">
			<#if study.ResultsAndDiscussion.FlashPoint?has_content>
				<para><emphasis role="bold">Flash point:</emphasis></para>
				<@keyPhyschem.flashPointList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.FlashPoint)/>
			</#if>
			<#if study.ResultsAndDiscussion.SustainingCombustibility?has_content>
				<para><emphasis role="bold">Sustaining combustibility:</emphasis></para>
				<@keyPhyschem.sustainingCombustabilityList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.SustainingCombustibility)/>
			</#if>
		<#elseif study.documentSubType=='Explosiveness'>
			<#if study.ResultsAndDiscussion.SmallScalePreliminaryTests?has_content>
				<para><emphasis role="bold">Small-scale preliminary tests:</emphasis></para>
				<@keyPhyschem.smallScalePrelimTestsList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.SmallScalePreliminaryTests)/>
			</#if>
			<#if study.ResultsAndDiscussion.ResultsOfTestSeriesForExplosives?has_content>
				<para><emphasis role="bold">All Test series for explosives:</emphasis></para>
				<#-- NOTE: i would change the way data display e.g. changing Test series for explosives by the actual test series-->
				<@keyPhyschem.resultsOfTestSeriesExplosivesList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.ResultsOfTestSeriesForExplosives)/>
			</#if>
		<#elseif study.documentSubType=='SurfaceTension'>
			<#if study.ResultsAndDiscussion.SurfaceTension?has_content>
				<para><emphasis role="bold">SurfaceTension:</emphasis></para>
				<@keyPhyschem.surfaceTensionList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.SurfaceTension)/>
			</#if>
		<#elseif study.documentSubType=="OxidisingProperties">
			<#if study.ResultsAndDiscussion.TestResultOxidisingGases?has_content>
				<para><emphasis role="bold">Oxidising gases:</emphasis></para>
				<@keyPhyschem.oxidisingGasesList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.TestResultOxidisingGases)/>
			</#if>
			<#if study.ResultsAndDiscussion.TestResultsOxidisingLiquids?has_content>
				<para><emphasis role="bold">Oxidising liquids:</emphasis></para>
				<@keyPhyschem.oxidisingLiquidsList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.TestResultsOxidisingLiquids)/>
			</#if>
			<#if study.ResultsAndDiscussion.TestResultsOxidisingSolids?has_content>
				<para><emphasis role="bold">Oxidising solids:</emphasis></para>
				<@keyPhyschem.oxidisingSolidsList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.TestResultsOxidisingSolids)/>
			</#if>
		<#elseif study.documentSubType=="Ph">
			<#if study.ResultsAndDiscussion.phValue?has_content>
				<para><emphasis role="bold">pH:</emphasis></para>
				<@keyPhyschem.phList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.phValue)/>
			</#if>
			<#if study.ResultsAndDiscussion.AcidityOrAlkalinity?has_content>
				<para><emphasis role="bold">Acidity / alkalinity:</emphasis></para>
				<@keyPhyschem.acidityList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.AcidityOrAlkalinity)/>
			</#if>
		<#elseif study.documentSubType=="Density">
			<#if study.ResultsAndDiscussion.Density?has_content>
				<para><emphasis role="bold">Density:</emphasis></para>
				<@keyPhyschem.densityList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.Density)/>
			</#if>
		<#elseif study.documentSubType=="StorageStability">
			<#if study.ResultsAndDiscussion.Results?has_content>
				<para><@com.text study.ResultsAndDiscussion.Results/></para>
			</#if>
			<#if study.ResultsAndDiscussion.TransformationProducts?has_content || study.ResultsAndDiscussion.IdentityTransformation?has_content>
				<para><emphasis role="bold">Transformation products: </emphasis><@com.picklist study.ResultsAndDiscussion.TransformationProducts/><?linebreak?>
					<@keyPhyschem.transformationList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.IdentityTransformation)/>
				</para>
			</#if>
			<#if study.ResultsAndDiscussion.ContainerMaterial?has_content>
				<para><emphasis role="bold">Reactivity towards container material:</emphasis></para>
				<@com.picklistMultiple study.ResultsAndDiscussion.ContainerMaterial/>
			</#if>

		<#elseif study.documentSubType=="StabilityThermal">
			<#if study.ResultsAndDiscussion.ThermalStability.TestSubstanceThermallyStable?has_content || study.ResultsAndDiscussion.ThermalStability.OperatingTemperature?has_content ||
					study.ResultsAndDiscussion.ThermalStability.Sublimation?has_content || study.ResultsAndDiscussion.ThermalStability.TransformationProducts?has_content || study.ResultsAndDiscussion.ThermalStability.IdentityTransformation?has_content >
				<para><emphasis role="HEAD-WoutNo">Thermal stability:</emphasis></para>
				<#if study.ResultsAndDiscussion.ThermalStability.TestSubstanceThermallyStable?has_content>
					<para>Test substance thermally stable: <@com.picklist study.ResultsAndDiscussion.ThermalStability.TestSubstanceThermallyStable/></para>
				</#if>
				<#if study.ResultsAndDiscussion.ThermalStability.OperatingTemperature?has_content>
					<para><emphasis role="bold">Operating temperature: </emphasis>
						<@keyPhyschem.operatingTempList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.ThermalStability.OperatingTemperature)/>
					</para>
				</#if>
				<#if study.ResultsAndDiscussion.ThermalStability.Sublimation?has_content>
					<para>Sublimation:<@com.picklist study.ResultsAndDiscussion.ThermalStability.Sublimation/></para>
				</#if>
				<#if study.ResultsAndDiscussion.ThermalStability.TransformationProducts?has_content || study.ResultsAndDiscussion.ThermalStability.IdentityTransformation?has_content>
					<para><emphasis role="bold">Transformation products: </emphasis><@com.picklist study.ResultsAndDiscussion.ThermalStability.TransformationProducts/><?linebreak?>
						<@keyPhyschem.transformationList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.ThermalStability.IdentityTransformation)/>
					</para>
				</#if>
			</#if>
			<#if study.ResultsAndDiscussion.StudyOnStability.StableToSunlight?has_content>
				<para><emphasis role="HEAD-WoutNo">Stability to sunlight</emphasis></para>
				<para>Test substance stable to sunlight: <@com.picklist study.ResultsAndDiscussion.StudyOnStability.StableToSunlight/></para>
			</#if>
			<#if study.ResultsAndDiscussion.StabilityToMetals.StableToMetals?has_content>
				<para><emphasis role="HEAD-WoutNo">Stability to metals</emphasis></para>
				<para>Test substance stable to metals / metal ions: <@com.picklist study.ResultsAndDiscussion.StabilityToMetals.StableToMetals/></para>
			</#if>
		<#elseif study.documentSubType=="DegreeOfDissolutionAndDilutionStability">
			<#if study.ResultsAndDiscussion.DegreeOfDissolution?has_content>
				<para><emphasis role="bold">Degree of dissolution: </emphasis>
					<@keyPhyschem.degreeDissolutionList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.DegreeOfDissolution)/>
				</para>
			</#if>
			<#if study.ResultsAndDiscussion.DilutionStability?has_content || study.ResultsAndDiscussion.DilutionStabilityMT41?has_content>
				<para><emphasis role="bold">Dilution stability: </emphasis>
					<@keyPhyschem.dilutionStabilityList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.DilutionStabilityMT41)/>
					<@keyPhyschem.dilutionStability2List studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.DilutionStability)/>
				</para>
			</#if>
			<#if study.ResultsAndDiscussion.DetailsOnResults?has_content>
				<para>Details:
					<@com.text study.ResultsAndDiscussion.DetailsOnResults/>
				</para>
			</#if>
		<#elseif study.documentSubType=="AdditionalPhysicoChemical">
			<#if study.ResultsAndDiscussion.Results?has_content>
				<para><@com.text study.ResultsAndDiscussion.Results/></para>
			</#if>

		<#elseif study.documentSubType=="EffectivenessAgainstTargetOrganisms">
			<#if study.ResultsAndDiscussion.DetailsOnResults?has_content>
				<para>Details:</para>
				<para role="indent"><@com.text study.ResultsAndDiscussion.DetailsOnResults/></para>
			</#if>

		<#--NOTE: this is for microorg, but at least in chemicals, it's used in ecotox-->
		<#elseif study.documentSubType=="ToxicityToOtherAboveGroundOrganisms" && keyBioPropMicro??>
			<#if study.ResultsAndDiscussion.EffectConcentrations?has_content>
				<para>Effect concentrations:
					<@keyBioPropMicro.effectList study.ResultsAndDiscussion.EffectConcentrations/>
				</para>
			</#if>
			<#if study.ResultsAndDiscussion.ResultsDetails?has_content>
				<para>Details:
					<@com.text study.ResultsAndDiscussion.ResultsDetails/>
				</para>
			</#if>
			<#if study.ResultsAndDiscussion.ResultsRefSubstance?has_content>
				<para>Results with reference substance:
					<@com.text study.ResultsAndDiscussion.ResultsRefSubstance/>
				</para>
			</#if>
			<#if study.ResultsAndDiscussion.Statistics?has_content>
				<para>Statistics:
					<@com.text study.ResultsAndDiscussion.Statistics/>
				</para>
			</#if>

		<#--5. Tox-->
		<#elseif study.documentSubType=="BasicToxicokinetics">
			<@keyTox.results_basicToxicokinetics study/>

		<#elseif study.documentSubType=="AcuteToxicityOral" || study.documentSubType=="AcuteToxicityDermal" ||  study.documentSubType=="AcuteToxicityInhalation" || study.documentSubType=="AcuteToxicityOtherRoutes" >
			<@keyTox.results_acuteToxicity study/>

		<#elseif study.documentSubType=="EyeIrritation">
			<@keyTox.results_eyeIrritation study/>

		<#elseif study.documentSubType=="SkinIrritationCorrosion">
			<@keyTox.results_skinIrritation study/>

		<#elseif study.documentSubType=="SkinSensitisation">
			<@keyTox.results_skinSensitisation study />

		<#elseif study.documentSubType=="PhototoxicityVitro">
			<@keyTox.results_phototoxicity study/>

		<#elseif study.documentSubType=="RepeatedDoseToxicityOral" || study.documentSubType=="RepeatedDoseToxicityInhalation" || study.documentSubType=="RepeatedDoseToxicityDermal" ||
					study.documentSubType=="RepeatedDoseToxicityOther" || study.documentSubType=="Carcinogenicity" || study.documentSubType=="Neurotoxicity" || study.documentSubType=="Immunotoxicity">
			<@keyTox.results_repDoseCarciNeuroImmuno study/>

		<#elseif study.documentSubType=="GeneticToxicityVitro" || study.documentSubType=="GeneticToxicityVivo">
			<@keyTox.results_geneticToxicity study/>
			<#-- NOTE: changed from existing macros-->

		<#elseif study.documentSubType=="ToxicityReproduction">
			<@keyTox.results_toxicityReproduction study/>

		<#elseif study.documentSubType=="ToxicityReproductionOther">
			<@keyTox.results_toxicityReproductionOther study/>

		<#elseif study.documentSubType=="DevelopmentalToxicityTeratogenicity">
			<@keyTox.results_developmentalToxicity study/>

		<#elseif study.documentSubType=="ToxicEffectsLivestock">
			<@keyTox.results_effectsLivestock study/>

		<#elseif study.documentSubType=="SpecificInvestigations">
			<@keyTox.results_specificInvestigation study/>

		<#elseif study.documentSubType=="EndocrineDisrupterMammalianScreening">
			<@keyTox.results_endocrineDisrupterMammalianScreening study/>

		<#elseif study.documentSubType=="DermalAbsorption">
			<@keyTox.results_dermalAbsorption study/>

		<#elseif study.documentSubType=="HealthSurveillanceData" ||  study.documentSubType=="ExposureRelatedObservationsOther" || study.documentSubType=="EpidemiologicalData" >
			<@keyTox.results_healthSurvExposureEpidemiological study/>

		<#elseif study.documentSubType=="DirectObservationsClinicalCases" || study.documentSubType="SensitisationData">
			<@keyTox.results_directObs study/>

		<#elseif study.documentSubType=="CellCultureStudy">
			<@keyTox.results_cellCulture study/>

		<#elseif study.documentSubType=="IntermediateEffects">
			<@keyTox.results_intermediateEffects study/>

		<#--8. Ecotox results -->
		<#elseif study.documentSubType=="ToxicityToBirds">
			<#--NOTE: probably could be merged with next-->
			<@keyEcotox.results_toxicityToBirds study/>

		<#elseif study.documentSubType=="ToxicityToOtherAboveGroundOrganisms" || study.documentSubType=="ShortTermToxicityToFish" ||
					study.documentSubType=="LongTermToxToFish" || study.documentSubType=="EndocrineDisrupterTestingInAqua" ||
					study.documentSubType=="ShortTermToxicityToAquaInv" || study.documentSubType=="LongTermToxicityToAquaInv"||
					study.documentSubType=="SedimentToxicity" || study.documentSubType=="ToxicityToAquaticAlgae" ||
					study.documentSubType=="ToxicityToAquaticPlant" || study.documentSubType=="ToxicityToTerrestrialArthropods" ||
					study.documentSubType=="ToxicityToSoilMacroorganismsExceptArthropods" ||
					study.documentSubType=="ToxicityToSoilMicroorganisms" || study.documentSubType=="ToxicityToTerrestrialPlants" ||
					study.documentSubType=="ToxicityToMicroorganisms" || study.documentSubType=="ToxicityToBees" ||
					study.documentSubType=="ToxicityToTerrestrialArthropodsOtherThanBees" || study.documentSubType=="ToxicityToSoilArthropods">
			<@keyEcotox.results_envToxicity study/>

		<#elseif study.documentSubType=="BioaccumulationAquaticSediment" || study.documentSubType=="BioaccumulationTerrestrial">
			<@keyEcotox.results_bioaccumulation study/>

		<#-- 6. Residues-->
		<#elseif study.documentSubType=="StabilityOfResiduesInStoredCommod">
			<@keyRes.results_stabilityOfResiduesInStoredCommod study/>

		<#elseif study.documentSubType=="ResiduesInLivestock">
			<@keyRes.results_residuesInLivestock study/>

		<#elseif study.documentSubType=="NatureResiduesInProcessedCommod">
			<@keyRes.results_natureResiduesInProcessedCommod study/>

		<#elseif study.documentSubType=="MigrationOfResidues">
			<@keyRes.results_migrationOfResidues study/>

		<#elseif study.documentSubType=="AdditionalInfoOnResiduesInFood" || study.documentSubType=="ExpectedExposureAndProposedAcceptableResidues">
			<#if study.ResultsAndDiscussion.DetailsOnResults?has_content>
				<para>Details:</para>
				<para role="indent"><@com.text study.ResultsAndDiscussion.DetailsOnResults/></para>
			</#if>

		<#elseif study.documentSubType=="ResiduesInRotationalCrops">
			<@keyRes.results_residuesInRotationalCrops study/>
		<#--				<para role="indent">[Excel]</para>-->

		<#elseif study.documentSubType=="MagnitudeResidInProcessedComm">
			<@keyRes.results_magnitudeResidInProcessedComm study/>
		<#--				<para role="indent">[Excel]</para>-->

		<#elseif study.documentSubType=="MetabolismInCrops" || study.documentSubType=="MetabolismInLivestock">
			<@com.emptyLine/>
			<para role="indent">[Add here the result tables obtained with the render tool of MSS Composer]</para>

		<#-- NOTE: "ResiduesProcessedCommodities" no specific results	-->

		<#--Analytical methods-->
		<#elseif study.documentSubType=="AnalyticalMethods">
			<@keyAnMeth.results_analyticalMethods study/>

		<#--FATE-->
		<#elseif study.documentSubType=="BiodegradationInSoil">
			<@keyFate.results_biodegradationInSoil study/>
			<#--NOTE: maybe could be combined with the other biodegradations-->

		<#elseif study.documentSubType=="PhotoTransformationInSoil" || study.documentSubType=="Phototransformation" ||
					study.documentSubType=="PhototransformationInAir">
			<@keyFate.results_phototransformation study/>
		
		<#elseif study.documentSubType=="FieldStudies">
			<@keyFate.results_fieldStudies study/>
		
		<#elseif study.documentSubType=="AdsorptionDesorption">
			<@keyFate.results_adsorptionDesorption study/>

		<#elseif study.documentSubType=="Hydrolysis">
			<@keyFate.results_hydrolysis study/>

		<#elseif study.documentSubType=="BiodegradationInWaterScreeningTests">
			<@keyFate.results_biodegradationWaterScreening study/>

		<#elseif study.documentSubType=="BiodegradationInWaterAndSedimentSimulationTests">
			<@keyFate.results_biodegradationWaterSedimentSimulation study/>

		<#elseif study.documentSubType=="MonitoringData">
			<@keyFate.results_monitoring study/>

		<#--Efficacy-->
		<#elseif study.documentSubType=="EfficacyData">
			<@keyEfficacy.results_efficacyData study/>
		</#if>

		<#-- Without specific results: "AgedSorption", "OtherDistributionData", "TransportViaAir",
			"AdditionalInformationOnEnvironmentalFateAndBehaviour"-->

		<#-- 2. Other information including tables + other HTML fields -->
		<#if includeRichTextFields>

			<@appendixEresults_richText study=study excludeOtherInfoDocSubTypes=["MetabolismInCrops","MetabolismInLivestock"]/>
		
		</#if>

			
	</#compress>
</#macro>

<#-- appendixEresults_richText prints the rich text fields in the results section, in most cases:
		- ResultsAndDiscussion.AnyOtherInformationOnResultsInclTables.OtherInformation
	but sometimes additional Rich Text fields can be found in results sections, and these are also
	considered. Also a few times the path might be a bit different so it is considered e.g. "ResultsAndDiscussions" 
	instead of "ResultsAndDiscussion"

	Inputs:
	- study: document object
	- excludeOtherInfoDocSubTypes: list of document sub types to exclude for printing the html in "Other information"
-->
<#macro appendixEresults_richText study excludeOtherInfoDocSubTypes>
	<#compress>

	<#-- get the right path for results -->
	<#if study.hasElement("ResultsAndDiscussion")>
		<#local resultsPath=study.ResultsAndDiscussion/>
	<#elseif study.hasElement("ResultsAndDiscussions")>
		<#local resultsPath=study.ResultsAndDiscussions/>
	</#if>

	<#-- get the right path to the main Rich Text field: OtherInformation is the most common field but there might be other 
		 also, exclude paths that should NOT be output
	-->
	<#if resultsPath.hasElement("AnyOtherInformationOnResultsInclTables")>
		
		<#if resultsPath.AnyOtherInformationOnResultsInclTables.hasElement("OtherInformation") &&
				resultsPath.AnyOtherInformationOnResultsInclTables.OtherInformation?has_content &&
				!(excludeOtherInfoDocSubTypes?seq_contains(study.documentSubType))>

			<para><emphasis role="bold">Other information</emphasis></para>
			<para><para style="background-color:#f7f7f7" role="indent"><@com.richText resultsPath.AnyOtherInformationOnResultsInclTables.OtherInformation/></para></para>
		</#if>
	</#if>

	<#-- Iterate over all other HTML fields if any -->
	<#list resultsPath?children as child>
		<#if child?node_type?contains("html") && child?node_name!="OtherInformation" && child?has_content>
			<#assign childName=child?node_name?replace("([A-Z]{1})", " $1", "r")?lower_case?cap_first/>
			<para>${childName}:</para>
			<para><para style="background-color:#f7f7f7" role="indent"><@com.richText child/></para></para>
		</#if>
	</#list>

	</#compress>

</#macro>

<#-- appendixEoverallRemarksAttachments prints the Overall Remarks section, which is rich-text.
	If selected, it prints images included in the attachment section.
	Eventually, this macro could be used to print metadata of the existing attachments 

	Inputs:
	- study: document object
	- includeImages: if true, print images of the attachments block
-->
<#macro appendixEoverallRemarksAttachments study includeRichTextFields=true includeImages=true>
	<#compress>

	<#if includeRichTextFields && study.OverallRemarksAttachments.RemarksOnResults?has_content>
		<para><emphasis role="bold">Overall remarks:</emphasis></para>
		<para><para style="background-color:#f7f7f7" role="indent"><@com.richText study.OverallRemarksAttachments.RemarksOnResults/></para></para>
	</#if>
	
	<#--4. Illustrations-->
	<#--  OLD CODE MODIFIED DUE TOO FORMAT CHANGES - 19/01/2023  -->
	<#--  <#if includeImages>
		<#if study.hasElement("OverallRemarksAttachments.IllustrationPicGraph") && study.OverallRemarksAttachments.IllustrationPicGraph?has_content>
			<para><emphasis role="bold">Illustrations / pictures / graphs:</emphasis></para>

			<#local illustration = iuclid.getMetadataForAttachment(study.OverallRemarksAttachments.IllustrationPicGraph) />
			<#if illustration?has_content && illustration.isImage>
				<#if illustration.exceedsLimit(10000000)>
					<para><emphasis>Image size is too big (${illustration.size} bytes) and cannot be displayed!</emphasis></para>
				<#elseif !iuclid.imageMimeTypeSupported(illustration.mediaType) >
					<para><emphasis>Image type (${illustration.mediaType}) is not yet supported!</emphasis></para>
				<#else>
					<figure>
						<title><@com.text illustration.filename/></title>
						<mediaobject>
							<imageobject>
								<imagedata width="70%" scalefit="1" fileref="data:${illustration.mediaType};base64,${iuclid.getContentForAttachment(study.OverallRemarksAttachments.IllustrationPicGraph)}" />
							</imageobject>
						</mediaobject>
					</figure>
				</#if>
			</#if>
		</#if>
	</#if>  -->

	<#--  PROPOSED CODE  -->
	<#if includeImages>
		<#if study.hasElement("OverallRemarksAttachments.AttachedBackgroundMaterial") && study.OverallRemarksAttachments.AttachedBackgroundMaterial?has_content>
			<para><emphasis role="bold">Illustrations / pictures / graphs:</emphasis></para>
			
			<#list study.OverallRemarksAttachments.AttachedBackgroundMaterial as row>
				<#if row.Type?has_content>
					<#assign attachmentType>
						<@com.picklist row.Type />
					</#assign>

					<#if attachmentType?contains("illustration (picture/graph)") && row.AttachedSanitisedDocsForPublication?has_content>
						<#local illustration = iuclid.getMetadataForAttachment(row.AttachedSanitisedDocsForPublication) />

						<#if illustration?has_content && illustration.isImage>
							<#if illustration.exceedsLimit(10000000)>
								<para><emphasis>Image size is too big (${illustration.size} bytes) and cannot be displayed!</emphasis></para>
							<#elseif !iuclid.imageMimeTypeSupported(illustration.mediaType) >
								<para><emphasis>Image type (${illustration.mediaType}) is not yet supported!</emphasis></para>
							<#else>
								<figure>
									<title><@com.text illustration.filename/></title>
									<mediaobject>
										<imageobject>
											<imagedata width="70%" scalefit="1" fileref="data:${illustration.mediaType};base64,${iuclid.getContentForAttachment(row.AttachedSanitisedDocsForPublication)}" />
										</imageobject>
									</mediaobject>
								</figure>
							</#if>
						</#if>
					</#if>
				</#if>
			</#list>
		</#if>
	</#if>

	</#compress>

</#macro>

<#-- resultStudyHashSummaryText prints a summary of the studies retrieved.

	In case of substances, it indicates how many studies have been reported for the active substance 
	and each of the metabolites.
	In case of product, only how many studies in total.

	This distinction is based on an assumption: for a product there is only one entity in the hash, while
	for substances there might be more than one (active substance, which is the subject, and metabolites)

	Inputs:
	- studyHash: hash containing study results i.e. studyHash['st']
	- subjectName: main ENTITY name
	- name: str with requirement name to print
-->
<#macro resultStudyHashSummaryText studyHash subjectName name>
	<#compress>
		<#local text=''/>
		<#local size=0/>
		<#list studyHash as entityName, resultData>
						
			<#local resultStudyList=resultData['records']/>

			<#local size = size + resultStudyList?size/>
			<#if (studyHash?keys?size>1)>
				<#local textEntity>
					<para role="indent">-
						${resultStudyList?size} for
						<#if entityName!=subjectName>metabolite ${entityName}<#else>active substance</#if>
					</para>
				</#local>

				<#local text = text + textEntity/>
			</#if>
		</#list>

		${size} individual <#if size==1>study<#else>studies</#if> for ${name} <#if size==1>is<#else>are</#if> summarised below: ${text}

	</#compress>
</#macro>

<#--
	metabolitesStudies prints all summaries and studies for a list of metabolites. If selected, first all the summaries will be printed and then
	all the studies. There are no sub-sections, and all documents are printed sequentially for EACH metabolite.

	This is used in the Tox section, only.
	NOTE: to be considered if to display results in the tox section as in the rest of the the sections i.e. together with the active substance.

	Inputs:
		- metabList: list of SUBSTANCE entities corresponding to metabolites
		- mixture: MIXTURE entity
		- activeSubstance: SUBSTANCE entity corresponding to the active substance
		- studySubTypes: string or list of strings defining document's sub type e.g. "AnalyticalMethods"
		- studyContext: list of hashmaps containing the conditions to be used to select which document(s) to output
			The hashmaps are definied in the ftls of the individual reports that use the appendixEstudies macro
			E.g. one example containing one condition for analytical methods for risk assessment is
				[{"path": "AdministrativeData.Endpoint", "val" : ["risk"], "qual" : "lk", "type" : "picklist"}] 
			Fur further description see 'filterStudyListbyContext' function
		- studyName: string with the name of the document to be displayed; if empty the name will be taken from the document subtype
		- summarySubTypes: list of summary document subtypes to be considered 
		- summaryMacroCall: name of the macro to be used to print summaries
		- includeStudies: bool; if true studies are printed. In combination with includeWaivers it can control if to print studies, waivers, or both. 
		- includeWaivers: bool; if true waivers are printed. In combination with includeStudies it can control if to print studies, waivers, or both. 
		- includeRichTextFields: bool; if true print rich text fields of materials and methods, results, and overall remarks sections
		- includeImages: bool; if true print attached images
-->
<#macro metabolitesStudies metabList=[] mixture="" activeSubstance="" studySubTypes=[] studyContext="" studyName="" summarySubTypes=[] summaryMacroCall="keyAppendixE.PPPsummary" 
				includeStudies=true includeWaivers=true includeRichTextFields=true, includeImages=true includeAnnotations=false>
	<#compress>

		<#-- if list of metabolites is empty, retrieve from the main mixture -->
		<#if (!metabList?has_content) && mixture?has_content>
			<#if activeSubstance?has_content>
				<#local metabList=com.getMetabolites(mixture, activeSubstance, true)/>
			<#else>
				<#local metabList=com.getMetabolites(mixture)/>
			</#if>
		</#if>

		<#if metabList?has_content>

			<@com.emptyLine/>

			<#-- print how many metabolites have been found and list their names -->
			<para>${metabList?size} metabolite dataset<#if metabList?size gt 1>s are<#else> is</#if> present <#if activeSubstance?has_content>for ${activeSubstance.ChemicalName}</#if>:
				<#if metabList?size gt 1>
					<#list metabList as metab>
						<para role="indent">
							- <command linkend="${metab.documentKey.uuid!}_${includeStudies?c}">${metab.ChemicalName}</command>
						</para>
					</#list>
				<#else>
					<command linkend="${metabList[0].documentKey.uuid!}">${metabList[0].ChemicalName}</command>
				</#if>
			</para>

			<@com.emptyLine/>

			<#-- iterate over the list of metabolites and get all studies-->
			<#list metabList as metab>

			<#-- create a section for each metabolites -->
			<sect3 xml:id="${metab.documentKey.uuid!}_${includeStudies?c}" label="-${metab_index+1}">
				<title role="HEAD-3">Metabolite ${metab.ChemicalName}</title>
				<#--				<para xml:id="${metab.documentKey.uuid!}" role="HEAD-5">-->
				<#--					<para><emphasis role="underline">----- Metabolite <emphasis role="bold">${metab.ChemicalName}</emphasis> -----</emphasis></para>-->
				<#--				</para>-->

				<#--Get all summaries-->
				<#if summaryMacroCall?has_content>
					<#local summaryFirst=true/>
					<#list summarySubTypes as summarySubType>
						<#local endSummary>ENDPOINT_SUMMARY.${summarySubType}</#local>
						<#local flexSummary>FLEXIBLE_SUMMARY.${summarySubType}</#local>
						<#if containsDoc(metab, [endSummary, flexSummary], "", false)>
							
							<#local summaryCallString = "<@" + summaryMacroCall + " metab  summarySubType false false/>"/>
							<#local summaryCall=summaryCallString?interpret/>
							<#local summary><@summaryCall/></#local>
	
							<#if summary?has_content>
								<#if summaryFirst>
									<#local summaryFirst=false/>
									<@com.emptyLine/>
									<para><emphasis role="HEAD-WoutNo">Summaries</emphasis></para>
									<para>Summaries for studies on metabolite ${metab.ChemicalName} are provided below:</para>
								</#if>
								
								<#local summaryDocFullName=summarySubType?replace("_EU_PPP", "")?replace("([A-Z]{1})", " $1", "r")?lower_case?cap_first/>
								<#if (summarySubTypes?size > 1)>
									${summary?replace('<emphasis role="HEAD-WoutNo">Summary</emphasis>',
													'-- for <emphasis role="HEAD-WoutNo">${summaryDocFullName}</emphasis>:')}
								<#else>
									${summary?replace('<para><@com.emptyLine/><emphasis role="HEAD-WoutNo">Summary</emphasis></para>', '')}
								</#if>
	
							</#if>
							<#if !summaryFirst && summarySubType_index==(summarySubTypes?size-1)>
								<@com.emptyLine/>
							</#if>
						</#if>
					</#list>
				</#if>

				<#--Get all studies-->
				<@com.emptyLine/>
				<@keyAppendixE.appendixEstudies subject=metab
					docSubTypes=studySubTypes context=studyContext name="Toxicity studies of metabolite ${metab.ChemicalName}"
					includeMetabolites=false includeStudies=includeStudies includeWaivers=includeWaivers includeRichTextFields=includeRichTextFields includeImages=includeImages includeAnnotations=includeAnnotations/>
			</sect3>
			</#list>
		</#if>
	</#compress>
</#macro>

<#-- createStudyHash creates a hash of studies for results and data waivers for all entities, taking into account
	the required context and/or section indicated to select studies/waivers.

	Inputs:
		- entities: list of ENTITIES that documents belong to
		- docSubTypes: string or list of strings defining document's sub type e.g. "AnalyticalMethods"
		- context: list of hashmaps containing the conditions to be used to select which document(s) to output
			The hashmaps are definied in the ftls of the individual reports that use the appendixEstudies macro
			E.g. one example containing one condition for analytical methods for risk assessment is
				[{"path": "AdministrativeData.Endpoint", "val" : ["risk"], "qual" : "lk", "type" : "picklist"}] 
			Fur further description see 'createStudyHash' function
		- section: string or list of strings containing the section(s) where the document needs to be cross-referenced in order to be output
			This is only applicable to the analytical methods section.
			E.g. section="6" or section=["7.1", "7.3"]
			
	Returns:
		- studyHash: hashmap, with two entries, one for studies 'st' and one for waivers 'dw':
			hash= {'st':{'name_of_entity1':[list of studies], 'name_of_entity2':[list of studies]..},
					'dw': {'name_of_entity1':[list of data waivers], 'name_of_entity2':[list of data waivers]..}
-->
<#function createStudyHash entities docSubTypes="" context="" section="">

	<#local studyHash_st={}/>
	<#local studyHash_dw={}/>

	<#list entities as entity>

		<#local entityName=getEntityName(entity)/>

		<#-- filter by type, context and section (the latter only if the global variable _doc2SectHashMap exists, currently only for analytical methods) -->
		<#local studyList = getStudyListByType(entity, docSubTypes)/>
		<#local studyList = filterStudyListbyContext(studyList, context)/>
        <#if _doc2SectHashMap??>
		    <#local studyList = filterStudyListbySection(studyList, section, _doc2SectHashMap)/>
        </#if>

		<#-- separate studies into real studies and data waiving documents -->
		<#local resultStudyList=getResultStudies(studyList)/>
		<#if resultStudyList?has_content>
			<#local studyHash_st = studyHash_st + {entityName:{'entity':entity, 'records': resultStudyList}}/>
		</#if>

		<#local dataWaivingStudyList=getDataWaivings(studyList)/>
		<#if dataWaivingStudyList?has_content>
			<#local studyHash_dw = studyHash_dw + {entityName:{'entity':entity, 'records': dataWaivingStudyList}}/>
		</#if>

	</#list>

	<#local studyHash = {'st':studyHash_st, 'dw':studyHash_dw}/>

	<#return studyHash/>
</#function>

<#-- getStudyListByType selects documents of the required sub type in an entity 
	The document types currently supported are FLEXIBLE_RECORD and ENDPOINT_STUDY_RECORD
	(NOTE: this assumes that a flexible record can never have the same sub type as an endpoint study record)

	Inputs:
		- entity: ENTITY that documents belong to
		- docSubTypes: string or list of strings defining document's sub type e.g. "AnalyticalMethods"
		
	Returns:
		- allStudyList: list of studies of the right type
-->
<#function getStudyListByType entity docSubTypes="">

	<#local allStudyList=[]/>

	<#local allStudyList=[]/>
	<#list docSubTypes as docSubType>
		<#if docSubType=="IntermediateEffects" || docSubType=="AnalyticalInformation">
			<#local studyList = iuclid.getSectionDocumentsForParentKey(entity.documentKey, "FLEXIBLE_RECORD", docSubType) />
		<#else>
			<#local studyList = iuclid.getSectionDocumentsForParentKey(entity.documentKey, "ENDPOINT_STUDY_RECORD", docSubType) />
		</#if>
		<#local allStudyList = allStudyList + studyList/>
	</#list>

	<#return allStudyList/>
</#function>

<#--
	filterStudyListbyContext filters a list of studies based on context rules provided.

	Inputs:
	- myStudyList: list of documents
	- context: hashmap containing a list of rules to be a applied to select documents
		Hashmaps are found in the specific ftls of the reports.
		The keys of each hashmap in the list are the following:
			- path: path to the element used to filter the documents
			- val: list of values to be checked
			- qual: the qualifier, 4 posibilities which determine the comparison:
				- 'eq': the value in path is EXACTLY ONE of the values in val e.g. val=["toxicity to bees", "toxicity to non-target arthropods"], path_value="toxicity to bees" OK
				- 'ne': the value in path is NONE of the values in val e.g. val=["toxicity to bees"], path_value="toxicity to non-target arthropods" OK
				- 'lk': the value in path CONTAINS at least one of the values in val e.g. val=["bee"], path_value="toxicity to bees" OK
				- 'nl': the value in path DOES NOT CONTAIN any of the values in val e.g. val=["bee"], path_value="toxicity to non-target arthropods" OK
			- type: the data type, currently only three options possible to extract the value to be compared:
				- "text": text value as is
				- "picklist": the picklist text without description or remarks
				- "picklistMultiple": the ";" separated concatenation of individual picklist values without description or remarks
		ALL the rules need to be valid in order for a study to be selected i.e. the list of rules are joined by AND
	
	Returns:
		- filtStudyList: list of studies after applying the context rules
-->
<#function filterStudyListbyContext myStudyList context>

	<#if myStudyList?has_content && context?has_content>

		<#local filtStudyList = [] />

		<#--Loop over studies-->
		<#list myStudyList as study>

			<#-- Flag to set number of conditions met-->
			<#local nbCondMet=0/>

			<#--Loop over conditions-->
			<#list context as ctxt>

				<#local contextPath = "study." + ctxt["path"] />
				<#local contextVal = contextPath?eval/>

				<#-- Convert value depending on type -->
				<#if ctxt["type"]=="picklistMultiple">

					<#local contextVal2>
						<#compress>
							<#list contextVal as ctxtVal>
								<@com.picklist picklistValue=ctxtVal locale="en" printOtherPhrase=false printDescription=false printRemarks=false /><#if ctxt_has_next>;</#if>
							</#list>
						</#compress>
					</#local>

				<#elseif ctxt["type"]=="picklist">

					<#-- get the value of the picklist without remarks!!-->
					<#local contextVal2>
						<@com.picklist picklistValue=contextVal locale="en" printOtherPhrase=false printDescription=false printRemarks=false />
					</#local>
				
				<#elseif ctxt["type"]=="text">
					<#local contextVal2><@com.text contextVal/></#local>
				</#if>

				<#-- Evaluate condition and change flag -->
				<#if ctxt["qual"]=="eq">
					<#if ctxt["val"]?seq_contains(contextVal2)>
						<#local nbCondMet=nbCondMet+1/>
					</#if>

				<#elseif ctxt["qual"]=="ne">
					<#if !ctxt["val"]?seq_contains(contextVal2)>
						<#local nbCondMet=nbCondMet+1/>
					</#if>

				<#elseif ctxt["qual"] == "lk">
					<#list ctxt["val"] as val>
						<#if contextVal2?contains(val)>
							<#local nbCondMet=nbCondMet+1/>
							<#break>
						</#if>
					</#list>

				<#elseif ctxt["qual"] == "nl">
					<#local notfound=true/>
					<#list ctxt["val"] as val>
						<#if contextVal2?contains(val)>
							<#local notfound=false/>
						</#if>
					</#list>
					<#if notfound><#local nbCondMet=nbCondMet+1/></#if>

				</#if>
			</#list>

			<#--Check if all conditions met and add study-->
			<#if nbCondMet==context?size>
				<#local filtStudyList = filtStudyList + [study] />
			</#if>
		</#list>
		<#return filtStudyList/>
	<#else>
		<#return myStudyList/>
	</#if>
</#function>

<!--
	filterStudyListbySection filters a list of studies by specific section numbers where the studies have been cross-referenced, 
	provided a global variable mapping documents to sections exists.

	Inputs:
	- studyList: list of study objects
	- section: string or list of strings indicating selected section numbers e.g. "5.1.1".
		NOTE: retrieval of the section is based on strict string matching at the beginning of a section numbering
			e.g. "5.1" would be matched by "5.1", "5.1.1", "5.1.2.1"..., but not by "4.5.1")
	- doc2sect: nested hashmap with document uuids as keys e.g.
		{'uuid1':{'name': X, 'endpoint': Y, 'section': [{'name': a, 'nb': b}, {'name': a2, 'nb': b2}, ..] }}
		NOTE: now it's by default the one used for analytical methods - not even passed as argument
	
	Returns:
	- secStudyList: list of filtered studies
-->
<#function filterStudyListbySection studyList section doc2sect>

	<#if studyList?has_content && section?has_content>

		<#local secStudyList = [] />

		<#if !(section?is_sequence)>
			<#local section=[section]/>
		</#if>

		<#list studyList as study>
			<#if _doc2SectHashMap?keys?seq_contains(study.documentKey.uuid)>
				<#local doc = _doc2SectHashMap[study.documentKey.uuid]/>
				<#local docSection = doc["section"]/>

				<#local docMainSection = docSection?sort_by("nb")[0]/>
				<#local docMainSectionNb = docMainSection["nb"]/>

				<#list section as sect>
					<#if docMainSectionNb?starts_with(sect)>
						<#local secStudyList  = secStudyList + [study]/>
						<#break>
					</#if>
				</#list>
			<#else>
				<#if section?seq_contains("NA")>
					<#local secStudyList  = secStudyList + [study]/>
				</#if>
			</#if>
		</#list>

		<#return secStudyList/>
	<#else>
		<#return studyList/>
	</#if>
</#function>

<#--
	getResultStudies filters a list of studies to get only those that are not waiving,
	by checking if they are data waiving using the isDataWaivingStudy function

	Inputs:
	- studyList: list of study objects
	
	Returns:
	- resultStudyList: list of filtered studies
-->
<#function getResultStudies studyList>
	<#local resultStudyList=[]/>
	<#if studyList?has_content>
		<#list studyList as study>
			<#if !isDataWaivingStudy(study)>
				<#local resultStudyList = resultStudyList + [study] />
			</#if>
		</#list>
	</#if>
	<#return resultStudyList/>
</#function>

<#--
	getDataWaivings filters a list of studies to get only those that are data waiving,
	by checking if they are data waiving using the isDataWaivingStudy function

	Inputs:
	- studyList: list of study objects
	
	Returns:
	- dataWaivingStudyList: list of filtered studies
-->
<#function getDataWaivings studyList>
	<#local dataWaivingStudyList=[]/>
	<#if studyList?has_content>
		<#list studyList as study>
			<#if isDataWaivingStudy(study)>
				<#local dataWaivingStudyList = dataWaivingStudyList + [study] />
			</#if>
	</#list>
	</#if>
	<#return dataWaivingStudyList/>
</#function>

<#--
	isDataWaivingStudy checks if a study is a data waiving, by checking two conditions:
	- AdministrativeData.DataWaiving has content
	- AdministrativeData.PurposeFlag is empty.
	If the field does not exist, it returns False.
	NOTE: this function could be improved.
	
	Inputs:
	- study: study object
	
	Returns: true or false
-->
<#function isDataWaivingStudy study>
	<#if !(study?has_content) || !(study.hasElement("AdministrativeData.DataWaiving"))>
		<#return false>
	</#if>
	<#local PurposeFlag = study.AdministrativeData.PurposeFlag />
	<#local DataWaiving = study.AdministrativeData.DataWaiving />
    <#return !(PurposeFlag?has_content) && DataWaiving?has_content />
</#function>

<#--
	getEntityName retrieves the name of a SUBSTANCE or MIXTURE ENTITY. 
	This corresponds to:
	- chemical name, in case of SUBSTANCE
	- mixture name, in case of MIXTURE
	NOTE: other entities are not covered
	
	Inputs:
	- entity: ENTITY object
	
	Returns: 
	- entityName: str with name
-->
<#function getEntityName entity>
	<#local entityName>
		<#compress>
			<#if entity.hasElement("ChemicalName")>
				<@com.text entity.ChemicalName/>
			<#elseif entity.hasElement("MixtureName")>
				<@com.text entity.MixtureName/>
			</#if>
		</#compress>
	</#local>
	<#return entityName>
</#function>

<#--
	getRequirementName gets the subtype of a document or list of documents and transforms its name to
	make it more readable i.e. adding spaces between words.
	If a specific name is provided, it overrides.

	Inputs:
	- name: str with required name
	- docSubTypes: str or list of str with document subtypes

	Returns:
	- name: str
-->
<#function getRequirementName name docSubTypes>

	<#if name=="">
		<#local name>
			<#compress>
				<#list docSubTypes as docSubType>
					${docSubType?replace("([A-Z]{1})", " $1", "r")?lower_case}<#if docSubType_has_next>, </#if>
				</#list>
			</#compress>
		</#local>
	</#if>

	<#return name>
</#function>
<#--
	getStudyReference gets the list of LITERATURE references in a study record
	e.g. ENDPOINT_STUDY_RECORD, sorted by literature type (GeneralInfo.LiteratureType).
	
	It uses the study.DataSource.Reference path.

	Inputs:
	- study: DOCUMENT object where references can be found in path DataSource.Reference
	- sorted_values: list of sorted values for the field GeneralInfo.LiteratureType in the LITERATURE entity

	Returns:
	- referenceList: list of LITERATURE entities, sorted by type 
-->
<#function getStudyReference study sorted_values = ["study report","publication","publication (copyright not owned for reproduction)","review article or handbook", "other company data", "other:"]>

	<#local referenceList=[]/>
	
	<#if study.hasElement("DataSource.Reference")>
		<#local referenceLinksList=study.DataSource.Reference/>
	<#elseif study.hasElement("AnalyticalInformation.DataSource.Reference")><#-- for AnalyticalInformation -->
		<#local referenceLinksList=study.AnalyticalInformation.DataSource.Reference/>
	</#if>
	
	<#if referenceLinksList?? &&  referenceLinksList?has_content>
		<#list referenceLinksList as referenceLink>
			<#local referenceEntry = iuclid.getDocumentForKey(referenceLink)/>
			<#local referenceList = referenceList + [referenceEntry]/>
		</#list>
	</#if>

	<#if referenceList?has_content && (referenceList?size > 1)>
		<#local referenceList = iuclid.sortByField(referenceList, "GeneralInfo.LiteratureType", sorted_values ) />
	</#if>
	
	<#return referenceList>
</#function>

<#--
	getReferenceElement extracts a specific element from a 
	list of LITERATURE entities. In case of more than one entity,
	the values or the elements are concatenated in the same string with a number
	between parenthesis.
	
	Inputs:
	- referenceList: list of LITERATURE entities
	- element: str with field path in LITERATURE entity
	- hyperlink: if true, retrieve element with hyperlink

	Returns:
	- referenceElement: str with the value for the element 
-->
<#function getReferenceElement referenceList element hyperlink=false>
	<#local referenceElement="">

	<#if referenceList?has_content>
		<#list referenceList as reference>
			
			<#-- get url -->
			<#local refUrl=iuclid.webUrl.documentView(reference.documentKey) />
			
			<#-- extract element -->
			<#local refElementPath = "reference." + element/>
			<#local refElement = refElementPath?eval/>

			<#-- get the element with the right printing macro -->
			<#local refElement><#if (referenceList?size>1)>(${reference_index+1})</#if>
				<#if hyperlink><ulink url="${refUrl}"></#if>

				<@com.value refElement/>
				
				<#if hyperlink></ulink></#if>
			</#local>

			<#-- add to list -->
			<#local referenceElement = referenceElement + refElement/>

		</#list>
	</#if>
	<#return referenceElement/>
</#function>

<#--
	getNoSid extracts the NoS ids and related remarks from a list of LITERATURE entities.
	Finding a NoS id relies only on the selection of the right picklist value.
	The NoS id format is NOT checked for correcteness i.e. EFSA-YYYY-DDDDDDDD
	
	Inputs:
	- referenceList: LITERATURE entity or list of LITERATURE entities
	- element: str with field path in LITERATURE entity
	- hyperlink: if true, retrieve element with hyperlink

-->
<#function getNoSid referenceList>

	<#local NoSIds=[]/>

	<#-- if it's a single LITERATURE convert to list -->
	<#if !referenceList?is_sequence>
		<#local referenceList = [referenceList]/>
	</#if>

	<#-- iterate -->
	<#list referenceList as reference>

		<#-- check study identifiers -->
		<#if reference.GeneralInfo.StudyIdentifiers?has_content>

			<#list reference.GeneralInfo.StudyIdentifiers as studyId>

				<#-- get idType and check if it's NoS id-->
				<#local idType><@com.picklist studyId.StudyIDType/></#local>

				<#if idType=="Notification of Studies (NoS) ID">

					<#-- if Id has content, retrieve; else report n.a.-->
					<#local NoSId><@com.text studyId.StudyID/></#local>
					<#if !NoSId?has_content><#local NoSId="n.a."/></#if>
					
					<#-- if remarks has content, retrieve and add to id -->
					<#local remark><@com.text studyId.Remarks/></#local>
					<#if remark?has_content>
						<#local NoSId = NoSId + ' (' + remark + ')'/>
					</#if>
					
					<#-- if id with remarks is not already in the list, add -->
					<#if !NoSIds?seq_contains(NoSId)>
						<#local NoSIds = NoSIds + [NoSId]/>
					</#if>
					
				</#if>
			</#list>
		</#if>
	</#list>

	<#-- join all ids by ';' -->
	<#if NoSIds?has_content>
		<#return NoSIds?join("; ")/>
	<#else>
		<#return "">
	</#if>

</#function>

<#--
	getGuidelines retrieves information from the guidelines used in a study.
	
	It uses the macro guidelineList (of common_module_studies_and_summaries) to retrieve guidelines 
	from the MaterialsAndMethods section, and in addition, retrieves info from
	MethodNoGuideline, if it has content. 
	
	The only exception is the intermediate effects document, for which a different strategy is followed.
	
	Inputs:
	- study: document object where guidelines are included

	Returns:
	- guidelines: str with guideline information

-->
<#function getGuidelines study>
	
	<#local guidelines><#compress>
		<#if study.hasElement("MaterialsAndMethods") && study.documentSubType!="IntermediateEffects">
			<@studyandsummaryCom.guidelineList study.MaterialsAndMethods.Guideline/>
			<#if study.MaterialsAndMethods.MethodNoGuideline?has_content>
				<para>other method: <@com.text study.MaterialsAndMethods.MethodNoGuideline/></para>
			</#if>
		<#elseif study.documentSubType=="IntermediateEffects">
			<@com.picklist study.MaterialsAndMethods.MethodUsed.Qualifier/> <@com.picklist study.MaterialsAndMethods.MethodUsed.MethodUsed/>
			<para><@com.text study.MaterialsAndMethods.MethodUsed.PrincipleOfTheMethod/></para>
		<#else>
			n.a.
		</#if>
	</#compress></#local>

	<#return guidelines>
</#function>

<#--
	getGuidelinesDeviation retrieves information on deviation from guidelines. Deviations are only displayed
	if 'yes', referring to which guideline they apply in case several guidelines were used.
	
	The strategy is common to all documents except Intermediate Effects.
	
	Inputs:
	- study: document object where guidelines are included

	Returns:
	- deviations: str with guideline deviation information
-->
<#function getGuidelinesDeviation study>

	<#local deviations=[]/>
	
	<#if study.hasElement("MaterialsAndMethods") && study.documentSubType!="IntermediateEffects">
		<#list study.MaterialsAndMethods.Guideline as guidelineKey>
			<#local deviation_text><@com.picklist guidelineKey.Deviation/></#local>
			<#if deviation_text?starts_with('yes')>
				<#local deviation><#compress>
					<#if guidelineKey?has_next || guidelineKey?index!=0>for <@com.picklist guidelineKey.Guideline/>: </#if>
					${deviation_text}
				</#compress></#local>
				<#local deviations = deviations + [deviation]/>
			</#if>
		</#list>

	<#elseif study.documentSubType=="IntermediateEffects">
		<#local deviation><@com.picklist study.MaterialsAndMethods.MethodUsed.Deviations/></#local>
		<#if deviation?starts_with('yes')>
			<#local deviations = deviations + [deviation]/>
		</#if>
	<#else>
		<#local deviations = ["n.a."]/>
	</#if>

	<#local deviations = deviations?join("; ")/>
	<#return deviations>
</#function>

<#--
	getChangeLogStatus checks if the study was previously used, by retrieving information
	from the change log: FLEXIBLE_RECORD.ChangeLog.
	
	By default, if the study (document UUID) is not in any change log, it returns "no" (it assumes
	the study was not previously used). If the document is found in a change log, then it returns
	a yes/no value (yes if the status is differnet than 'new') together with the status and remarks.
	If the document is listed more than once in all change logs, the statuses are concatenated.
	
	Inputs:
	- study: document object where guidelines are included
	- entity: ENTITY object where the change log is found

	Returns:
	- changeLogStatusMessage: str with the message on "previously used" to be displayed
-->
<#function getChangeLogStatus study entity>
	
	<#local changeLogEntryList=[]/>

	<#-- default flag for change log -->
	<#local changeLogFlag="no"/>

	<#-- retrieve change log documents -->
	<#local changeLogs = iuclid.getSectionDocumentsForParentKey(entity.documentKey, "FLEXIBLE_RECORD", "ChangeLog") />

	<#-- iterate over changelog dicuments and entries-->
	<#list changeLogs as changeLog>
		
		<#list changeLog.ChangeLog.ChangeLogEntries as changeLogEntry>
			
			<#-- get the document linked in the change log entry and check if it corresponds to current study doc (same uuid),
				If it does, then retrieve the status and add to the list
			-->
			<#local changeLogDoc=iuclid.getDocumentForKey(changeLogEntry.LinkToDocument)/>

			<#if changeLogDoc?has_content>

				<#if study.documentKey.uuid==changeLogDoc.documentKey.uuid>
					
					<#local changeLogStatus><@com.picklist changeLogEntry.Status/></#local>
					
					<#if changeLogStatus?has_content>

						<#-- if status is "new", then change flag to 'yes' -->
						<#if !(changeLogStatus?starts_with("new"))>
							<#local changeLogFlag="yes"/>
						</#if>

						<#-- add the change log entry to the list if status is set -->
						<#local changeLogEntryList = changeLogEntryList + [changeLogEntry]/>
					</#if>
				</#if>
			</#if>
		</#list>
	</#list>
	
	<#-- create the message to be displayed using:
		- the flag (yes or no)
		- the status with remarks (if multiple, concatenate separated by |)
	-->
	<#local changeLogStatusMessage>${changeLogFlag}
		<#if changeLogEntryList?has_content>
			<#list changeLogEntryList as clEntry>
				(<@com.picklist clEntry.Status/>)<#if clEntry.Remark?has_content> - <@com.text clEntry.Remark/></#if>
				<#if clEntry?has_next>|</#if>
			</#list>
		</#if>
	</#local>

	<#return changeLogStatusMessage>
</#function>

<#--
	getGLP retrieves GLP and related information from a study, by checking the fields:
		- GLPComplianceStatement
		- OtherQualityAssurance
		- ComplianceWithQualityStandards
	For intermediate effects a different path is used.  
	
	Inputs:
	- study: document object where guidelines are included

	Returns:
	- glpInfo: str with information on GLP
-->
<#function getGLP study>

	<#local glpInfo><#compress>

		<#-- This is the general path applicable to most documents -->
		<#if study.hasElement("MaterialsAndMethods") && study.documentSubType!="IntermediateEffects">
			<@com.picklist study.MaterialsAndMethods.GLPComplianceStatement/>

			<#--NOTE: this path is not always present so better to check that it exists first-->
			<#if study.hasElement("MaterialsAndMethods.OtherQualityAssurance") && study.MaterialsAndMethods.OtherQualityAssurance?has_content>
				<?linebreak?>other quality assurance: <@com.picklist study.MaterialsAndMethods.OtherQualityAssurance/>
			</#if>
			<#if study.hasElement("MaterialsAndMethods.ComplianceWithQualityStandards") && study.MaterialsAndMethods.ComplianceWithQualityStandards?has_content>
				<?linebreak?>compliance with quality standards: <@com.picklist study.MaterialsAndMethods.ComplianceWithQualityStandards/>
			</#if>

		<#-- for Intermediate Effects -->
		<#elseif study.documentSubType=="IntermediateEffects">
			<@com.picklist study.MaterialsAndMethods.MethodUsed.GLPCompliance/>
			<?linebreak?>
			<#if study.MaterialsAndMethods.MethodUsed.OtherQualityFollowed?has_content>
				other quality assurance: <@com.picklist study.MaterialsAndMethods.MethodUsed.OtherQualityFollowed/>
			</#if>

		<#else>
			n.a.
		</#if>
	</#compress></#local>

	<#return glpInfo/>

</#function>

<#--
	sortByEndpoint sorts a list of studies so that studies with the same
	endpoint appear sequentially in the list.

	Input:
	- sortByEndpoint: list of document objects to be sorted

	Returns:
	- sortedStudies: sorted list of document objects
-->
<#function sortByEndpoint myStudyList>

	<#-- create a hashmap to sort by endpoint (same endpoints together)-->
	<#local studyHashMap={}/>
	<#list myStudyList as study>
		<#local endpoint><@com.picklist study.AdministrativeData.Endpoint/></#local>
		<#if studyHashMap[endpoint]??>
			<#local entry = studyHashMap[endpoint] + [study]/>
			<#local studyHashMap = studyHashMap + {endpoint : entry}/>
		<#else>
			<#local studyHashMap = studyHashMap + {endpoint:[study]}/>
		</#if>
	</#list>

	<#-- read hashmap and get ordered list-->
	<#local sortedStudies=[]/>
	<#list studyHashMap?keys as key>
		<#local sortedStudies = sortedStudies + studyHashMap[key]/>
	</#list>

	<#return sortedStudies/>
</#function>

<#-- 
	dataWaiver prints data waivers from a list of documents.
	
	This substitutes the macro in macros_common_studies_and_summaries.

	Inputs:
	- dwList: list of study objects being data waiver
	- endpoint: str with endpoint name to print
-->
<#macro dataWaiver dwList endpoint="">
	<#compress>
		<#if dwList?has_content>
			<#list dwList as study>
				<#if study?has_content>
	
					<sect4 xml:id="${study.documentKey.uuid!}" label="" role="NotInToc">
						
						<para><emphasis role="bold"><@com.text study.name/></emphasis>:</para>
						
						<para role="indent"><emphasis role="bold">Information requirement: </emphasis>
						 	<#if study.AdministrativeData.Endpoint?has_content>
						 		<@com.picklist study.AdministrativeData.Endpoint/>
						 	<#else>
						 		${endpoint!}
							</#if>
						</para>
	
						<para role="indent">
							<emphasis role="bold">Reason: </emphasis>
							<@com.picklist study.AdministrativeData.DataWaiving/>
						</para>
				
						<para role="indent">
							<emphasis role="bold">Justification:</emphasis>
							<@com.picklistMultiple study.AdministrativeData.DataWaivingJustification/>
						</para>
		
					</sect4>
				</#if>
			</#list>
		</#if>
	</#compress>
</#macro>

<#--
	containsDoc checks if an entity contains a set of documents, with a specific
	context or cross-reference section, if provided.
	It returns true if at least ONE of the documents is present.

	Input:
	- subject: ENTITY object 
	- docTypesSubTypes: document type and subtype OR list of document types and subtypes e.g. ['ENDPOINT_STUDY_RECORD.Ph']
	- context: list of hashmaps containing the conditions to be used to select which document(s) to output
			The hashmaps are definied in the ftls of the individual reports that use the appendixEstudies macro
			E.g. one example containing one condition for analytical methods for risk assessment is
				[{"path": "AdministrativeData.Endpoint", "val" : ["risk"], "qual" : "lk", "type" : "picklist"}] 
			Fur further description see 'filterStudyListbyContext' function
	- includeMetabolites: bool; if true, studies of the selected type in metabolite datasets will also be output
			This requires the global variable _metabolites to exist and have content.
			It is applicable for reports on the active substance (where metabolite studies should be also listed)
	- section: string or list of strings containing the section(s) where the document needs to be cross-referenced in order to be output
		This is only applicable to the analytical methods section.
		E.g. section="6" or section=["7.1", "7.3"]

	Returns: true or false
-->
<#function containsDoc subject docTypesSubTypes context=[] includeMetabolites=true section="">

	<#-- convert to list if only one doc type and subtype provided as string -->
	<#if !docTypesSubTypes?is_sequence>
		<#local docTypesSubTypes=[docTypesSubTypes]/>
	</#if>
	
	<#-- add metabolites if required -->
	<#local entities=[subject]/>
	<#if includeMetabolites && _metabolites?? && _metabolites?has_content>
		<#local entities = entities + _metabolites/>
	</#if>
	
	<#-- iterate through list of docs -->
	<#list docTypesSubTypes as docTypeSubType>

		<#local docTypeSubtypeList=docTypeSubType?split(".")/>
		
		<#local docList=[]/>
		<#list entities as entity>
			<#attempt>
				<#local docList = docList + iuclid.getSectionDocumentsForParentKey(entity.documentKey, docTypeSubtypeList[0] , docTypeSubtypeList[1])/>
			<#recover>

			</#attempt>

		</#list>
		
		<#if context?has_content>
			<#local docList=filterStudyListbyContext(docList, context)/>
		</#if>
		
		<#if _doc2SectHashMap?? && section?has_content>
		    <#local studyList = filterStudyListbySection(docList, section, _doc2SectHashMap)/>
        </#if>
		
		<#if docList?has_content>
			<#return true>
		</#if>
	</#list>

	<#return false>
</#function>

<#-- note: when merging, maybe append the title of the summary at the beginning of the paragraph-->
<#macro PPPsummary subject docSubTypes merge=false includeMetabolites=true includeAnnotations=false endpoint="">
	<#compress>

		<#--Get all documents, from same or different type-->
		<#if !docSubTypes?is_sequence>
			<#local docSubTypes=[docSubTypes]/>
		</#if>

		<#--Ensure merge=false for non compatible summary types
			NOTE: only allowed for Ecotox, Tox, with the exception of some docs
		-->
		<#--  <#if !keyEcotox?? && !keyTox?? && docSubTypes?seq_contains("AquaticToxicityRacReporting")>
			<#local merge=false>
		</#if>  -->

		<#-- Get all entities (subject and metabolites, if they exist) -->
		<#local entities=[subject]/>
		<#if includeMetabolites && _metabolites?? && _metabolites?has_content>
			<#local entities = entities + _metabolites/>
		</#if>

		<#-- Get all summaries for each entity into a hash-->
		<#local entity2summaryHash = {}/>

		<#list entities as entity>
			
			<#local entitySummaryList=[]/>
			
			<#list docSubTypes as docSubType>
				<#if docSubType=="AquaticToxicityRacReporting" || docSubType?matches("EstConc.*") || docSubType=="NonDietaryExpo" || docSubType=="ToxRefValues" || docSubType=="EndocrineDisruptingPropertiesAssessmentPest" || docSubType=="ResiduesInLivestock" || docSubType=="MRLProposal" || docSubType=="ExpectedExposure" || docSubType=="DefinitionResidueFate"> <#-- to change? -->
					<#local summaryList = iuclid.getSectionDocumentsForParentKey(entity.documentKey, "FLEXIBLE_SUMMARY", docSubType) />
				<#else>
					<#local summaryList = iuclid.getSectionDocumentsForParentKey(entity.documentKey, "ENDPOINT_SUMMARY", docSubType) />
				</#if>
				<#local entitySummaryList = entitySummaryList + summaryList/>
			</#list>
			
			<#if entitySummaryList?has_content>
				<#if entity.documentType=="MIXTURE">
					<#local entityName=entity.MixtureName/>
				<#elseif entity.documentType=="SUBSTANCE">
					<#local entityName=entity.ChemicalName/>
				</#if>
				<#local entity2summaryHash = entity2summaryHash + { entityName : {'summaries':entitySummaryList, 'entity':entity}}/>
			</#if>
		</#list>

		<#-- print "Summary" regardless if there is content or not -->
		<para><@com.emptyLine/><emphasis role="HEAD-WoutNo">Summary</emphasis></para>

		<#-- Iterate through summaries and create section lists for each entity -->
		<#if !entity2summaryHash?has_content>
			
			<@com.emptyLine/>
			<para>No summary information available for this section.</para>
			<@com.emptyLine/>

		<#else>
			
			<#list entity2summaryHash as entityName, entityData>
				
				<#local allSummaryList=entityData['summaries']/>
				<#local entity=entityData['entity']/>

				<#-- create variables for the different sections, in order to be able to merge -->
				<#local keyInfoList=[]/>
				<#local linksList=[]/>
				<#local endpointsHash={}/>
				<#local higherTierList=[]/>
				<#local higherTierLinksList=[]/>
				<#local justificationList=[]/>
				<#local discussionList=[]/>

				<#if allSummaryList?has_content>

					<#-- print numbering for summaries if there is more than one for an entity -->
					<#local printSummaryIndex = allSummaryList?size gt 1 />

					<#-- print a header for metabolites -->
					<#if _metabolites?? && _metabolites?has_content && entityName!=subject.ChemicalName>
						<@com.emptyLine/>
						<para><emphasis role="underline">----- Metabolite <emphasis role="bold">${entityName}</emphasis> -----</emphasis></para>
						<@com.emptyLine/>
					</#if>

					<#-- iterate over summaries for the entity -->
					<#local summaryLinks = []/>
					<#list allSummaryList as summary>

						<#-- get url and link-->
						<#local summaryUrl=iuclid.webUrl.documentView(summary.documentKey) />
						<#local summaryLink><ulink url="${summaryUrl}"><@com.text summary.name/></ulink></#local>
						
						<#if (!merge)>
							<#-- if not merge, print the summary title with the link -->
							<para><emphasis role="bold"><#if printSummaryIndex>#${summary_index+1}: </#if>${summaryLink}</emphasis></para>
						<#else>
							<#-- if merge, make a list of links -->
							<#local summaryLinks = summaryLinks + [summaryLink]/>
						</#if>

						<#-- Key information 
							NOTE: in EstConc summaries the field is KeyInformation.field357
						-->
						<#local keyInfo = getSummaryRichTextSection(summary, ["KeyInformation.KeyInformation", "KeyInformation.field357"])/>
						<#if keyInfo?has_content>
							<#if merge>
								<#local keyInfoList =  keyInfoList + [keyInfo]/>
							<#else>
								<para><emphasis role="bold">Key information: </emphasis></para>${keyInfo}
							</#if>
						</#if>
						
						<#-- Links, only if they are is not CSA (where they would appear)
								NOTE: in EstConc summaries RelevantSummaries.InputSummaries
						 -->
						<#local CSApath = studyandsummaryCom.getObjectFromPathOptions(summary, ["KeyValueForChemicalSafetyAssessment", "KeyValueChemicalAssessment", "ResultsAndDiscussion"])/>
						<#if !CSApath?has_content>
							<#local links = studyandsummaryCom.getSummaryLinks(summary, ["LinkToRelevantStudyRecord.Link", "RelevantSummaries.InputSummaries"], 'indent')/>
							<#if links?has_content>
								<#if merge>
									<#local linksList =  linksList + [links]/>
								<#else>
									<para><emphasis role="bold">Link to relevant study records: </emphasis></para>${links}
								</#if>
							</#if>
						</#if>

						<#--CSA value: depends on the summary or group of summaries -->
						<#if !merge>
							<#local csaTable><#compress>
								<#if _section??>
									<#if _section=="Ecotox" && keyEcotox??>
										<@keyEcotox.ecotoxCSA summary/>
									
									<#elseif _section=="Fate" && keyFate??>
										<@keyFate.fateCSA summary endpoint/>
									
									<#elseif _section=="Biopropmicro" && keyBioPropMicro??>
										<#-- it's only one summary, and might change -->
										<#if summary.documentSubType=="ToxicityToOtherAboveGroundOrganisms">
											<@keyBioPropMicro.toxicityToOtherAboveGroundOrganismsSummaryTable summary/>
										</#if>

									<#elseif _section =="Physchem" && keyPhysChemSummary?? && CSApath?has_content>
										<@keyPhysChemSummary.physicalChemicalPropertiesTable _subject=entity selectedDocSubTypes=[summary.documentSubType] printTitle=false includeMetabolites=false/>

									<#elseif _section=="Tox" && keyTox??>
										<@keyTox.toxCSAtable summary/>

									<#elseif _section=="Residues" && keyRes??>
										<@keyRes.residuesSummaryTable summary/>

									</#if>
								</#if>
							</#compress></#local>
							
							<#if csaTable?has_content>
								<#if _section?? && _section != "Residues">
									<para><emphasis role="bold">Key value for assessment: </emphasis></para>
								</#if>

								<para role='small'>${csaTable}</para>
							</#if>

						</#if>

						<#-- transformation products (for fate)-->
						<#if !merge && keyFate?? && summary.hasElement("InformationOnTransformationProducts") && summary.InformationOnTransformationProducts?has_content>
							<para><emphasis role="bold">Information on transformation products: </emphasis></para>
							<para role='small'><@keyFate.transformationProductsSummaryTable summary/></para>
						</#if>
					
						<#--Hier tier testing-->
						<#local higherTier = getSummaryRichTextSection(summary, ["KeyValueForChemicalSafetyAssessment.HigherTierTesting.KeyInformationFromHigherTierTesting"])/>
						<#local higherTierLinks = studyandsummaryCom.getSummaryLinks(summary, ["KeyValueForChemicalSafetyAssessment.HigherTierTesting.LinkToRelevantStudyRecord"], 'indent2')/>
						<#if higherTier?has_content || higherTierLinks?has_content>
							<#if merge>
								<#local higherTierList =  higherTierList + [higherTier]/>
								<#local higherTierLinksList =  higherTierLinksList + [higherTierLinks]/>
							<#else>
								<para><emphasis role="bold">Higher tier testing: </emphasis></para>${higherTier}
								<#if higherTierLinks?has_content>
									<para><para role='indent' style="background-color:#f7f7f7">Link to relevant study records:${higherTierLinks}</para></para>
								</#if>
							</#if>
						</#if>

						<#-- Justification (Tox, Physchem) -->
						<#local justification = getSummaryRichTextSection(summary, ["Justification.Remarks"])/>
						<#if justification?has_content>
							<#if merge>
								<#local justificationList =  justificationList + [justification]/>
							<#else>
								<para><emphasis role="bold">Justification for classification or non-classification: </emphasis></para>${justification}
							</#if>
						</#if>

						<#--Discussion-->
						<#local discussion = getSummaryRichTextSection(summary, ["Discussion.Discussion"])/>
						<#if discussion?has_content>
							<#if merge>
								<#local discussionList =  discussionList + [discussion]/>
							<#else>
								<para><emphasis role="bold">Additional information: </emphasis></para>${discussion}
							</#if>
						</#if>

						<#--  Annotations  -->
						<#if !merge && includeAnnotations>
							<#--  <para><emphasis role="bold">Assessment and conclusion by Evaluating Competent Authority:</emphasis></para>  -->
							<@printAnnotationsforDoc summary />
						</#if>
					</#list>

					<#if merge>

						<#-- print titles -->
						<para><emphasis role="bold"><#if ( (summaryLinks?size) > 1) >Merge of ${summaryLinks?size} summaries: </#if>${summaryLinks?join("; ")}</emphasis></para>

						<#-- key info -->
						<#if keyInfoList?has_content>
							<para><emphasis role="bold">Key information: </emphasis></para>
							${keyInfoList?join("")}
						</#if>

						<#if linksList?has_content>
							<para><emphasis role="bold">Link to relevant study records: </emphasis></para>
							${linksList?join("")}
						</#if>  

						<#-- csa table (only possible for new documents which can be merged)-->
						<#local csaTable><#compress>
							<#if _section??>
								<#if _section=="Ecotox" && keyEcotox??>
									<@keyEcotox.ecotoxCSA allSummaryList/>
								<#elseif _section=="Fate" && keyFate??>
									<@keyFate.fateCSA allSummaryList/>	
								<#elseif _section =="Physchem" && keyPhysChemSummary??>
									<@keyPhysChemSummary.physicalChemicalPropertiesTable _subject=entity selectedDocSubTypes=docSubTypes printTitle=false includeMetabolites=false/>
								<#elseif _section=="Tox" && keyTox??>
									<@keyTox.toxCSAtable allSummaryList/>
								<#elseif _section=="Residues" && keyRes??>
									<@keyRes.residuesSummaryTable allSummaryList/>
								</#if>
							</#if>
						</#compress></#local>
						<#if csaTable?has_content>
							<#if _section?? && _section != "Residues">
								<para><emphasis role="bold">Key value for assessment: </emphasis></para>
							</#if>
							<para role='small'>${csaTable}</para>
						</#if>

						<#-- transformation products (for fate)-->
						<#if _section=="Fate" && keyFate??>
							<#local trProdTable><@keyFate.transformationProductsSummaryTable allSummaryList/></#local>
							<#if trProdTable?has_content>
								<para><emphasis role="bold">Information on transformation products: </emphasis></para>
								<para role='small'>${trProdTable}</para>
							</#if>
						</#if>

						<#-- higher tier (for ecotox) -->
						<#if higherTierList?has_content || higherTierLinksList?has_content>
							<para><emphasis role="bold">Higher tier testing: </emphasis></para>
							${higherTierList?join("")}
							<#if higherTierLinksList?has_content>
								<para><para role='indent' style="background-color:#f7f7f7">Link to relevant study records:${higherTierLinksList?join("")}</para></para>
							</#if>
						</#if>

						<#-- justification (for tox, physchem) -->
						<#if justificationList?has_content>
							<para><emphasis role="bold">Justification for classification or non-classification: </emphasis></para>
							${justificationList?join("")}
						</#if>

						<#-- discussion -->
						<#if discussionList?has_content>
							<para><emphasis role="bold">Additional information:</emphasis></para>
							${discussionList?join("")}
						</#if>

						<#--  Annotations  -->
						<#if includeAnnotations>
							<#--  <para><emphasis role="bold">Assessment and conclusion by Evaluating Competent Authority:</emphasis></para>  -->
							<@printAnnotationsforDoc allSummaryList true />
						</#if>
					</#if>
				</#if>
			</#list>
		</#if>
	</#compress>
</#macro>

<#-- 
    This macro generates an HTML table displaying annotations information for a given document 
	or list of documents. It retrieves the annotations from IUCLID documents provided as 
	parameter and filters them out based on their type ("evaluation" annotations). The macro 
	supports handling a single document or a sequence (list) of documents.
-->
<#macro printAnnotationsforDoc docList merge=false>
	<#compress>
		<#--  Initialize variable that will hold list of annotations  -->
		<#local annotationsList = [] />

		<#--  Get list of annotations from list of documents  -->
		<#if docList?is_sequence>
            <#list docList as doc>
				<#local annotationsList = annotationsList + getAnnotationsListFromDoc(doc) />
            </#list>
        <#else>
			<#local annotationsList = getAnnotationsListFromDoc(docList) />
        </#if>

		<#--  Check if list of annotations has content  -->
		<#if annotationsList?size gt 0>
			<#--  Iterate over list of annotations and create rows in the table  -->
			<#list annotationsList as annotation>
				<#--  Create annotations table  -->
				<table border="1">
					<#--  Set table title  -->
					<title>
						Evaluation by Competent Authorities<#if annotationsList?size gt 1> (${annotation?counter} of ${annotationsList?size})</#if>
					</title>

					<#--  Define columns width  -->
					<col width="25%" />
					<col width="75%" />

					<thead valign="middle">
						<tr>
							<th colspan="2" align="center"><?dbfo bgcolor="#ccc" ?>
								<emphasis role="bold">${annotation.title}</emphasis>
							</th>
						</tr>
					</thead>

					<#--  Define table body  -->
					<tbody valign="middle">
						<#--  Iterate over annotation and print admin data  -->
						<#list annotation.admin as key, value>
							<tr>
								<td><emphasis role="bold">${key}</emphasis></td>
								<td>${value}</td>
							</tr>
						</#list>
						
						<#--  Iterate over annotation and print evaluation data  -->
						<#list annotation.evaluation as key, value>
							<tr>
								<td><emphasis role="bold">${key}</emphasis></td>
								<td>${value}</td>
							</tr>
						</#list>

						<#--  Conclusions and executive summary  -->
						<tr>
							<td colspan="2">
								<#if annotation.conclusions?has_content>
									<para><emphasis role="bold">Conclusions:</emphasis></para>
									${annotation.conclusions}
								</#if>

								<#if annotation.conclusions?has_content && annotation.executiveSummary?has_content>
									<@com.emptyLine/>
								</#if>

								<#if annotation.executiveSummary?has_content>
									<para><emphasis role="bold">Executive summary:</emphasis></para>
									${annotation.executiveSummary}
								</#if>

								<#if !annotation.conclusions?has_content && !annotation.executiveSummary?has_content>
									No conclusions/executive summary available
								</#if>
							</td>
						</tr>
					</tbody>
				</table>
			</#list>
		</#if>
	</#compress>
</#macro>

<#--
    This function retrieves a list of annotations for a given document. It iterates over the 
	annotation keys of the document and filters them out based on their type ("evaluation" 
	annotations). For each matching annotation, it extracts relevant information such as the 
	annotation type, name, authority, and last update date.
    The function constructs a list of annotation entries, where each entry is represented by a 
	sublist containing the document link, annotation name, annotation type, and annotation 
	authority. The resulting list of annotation entries is returned by the function.
-->
<#function getAnnotationsListFromDoc doc>
	<#--  Initialize variable that will hold list of annotations for single document  -->
	<#local annotationsList = [] />

	<#--  Get document URL and link  -->
	<#local docUrl=iuclid.webUrl.documentView(doc.documentKey) />
	<#local docLink><ulink url="${docUrl}"><@com.text doc.name/></ulink></#local>

	<#--  Get list of annotation keys  -->
	<#local annotationKeys = doc.annotations />

	<#--  Iterate over list of annotation keys  -->
	<#list annotationKeys as key>
		<#--  Initialize hash that holds annotation data  -->
		<#local annotationHash = {} />

		<#--  Initialize hash that holds administrative data for an annotation  -->
		<#local adminHash = {} />

		<#--  Initialize hash that holds evaluation data for an annotation  -->
		<#local evalHash = {} />

		<#--  Get annotation  -->
		<#local annotation = iuclid.getDocumentForKey(key) />

		<#--  Get annotation type  -->
		<#local annotationType>
			<@com.picklist annotation.AdminInfo.AnnotationType />
		</#local>

		<#--  Get annotation status  -->
		<#local annotationStatus>
			<@com.picklist annotation.AdminInfo.AnnotationStatus />
		</#local>

		<#--  Check if annotation type is equal to "evaluation"  -->
		<#if annotationType?matches("evaluation") && annotationStatus?matches("final")>
			<#--  Get annotation name  -->
			<#local annotationName>
				<#if annotation.AdminInfo.Name?has_content>
					<ulink url="${docUrl}"><@com.text annotation.AdminInfo.Name/></ulink>
				</#if>
			</#local>
			<#--  Add annotation name to annotation hash  -->
			<#local annotationHash = annotationHash + {"title" : annotationName}>

			<#--  Get annotation authority  -->
			<#local annotationAuthority>
				<@com.text annotation.AdminInfo.Authority/>
			</#local>
			<#--  Add annotation authority to admin hash  -->
			<#local adminHash = adminHash + {"Authority/organization" : annotationAuthority!}>

			<#--  Get creation date  -->
			<#assign annotationDateCreated = getDateCreated(annotation) />
			<#--  Add creation date to admin hash  -->
			<#local adminHash = adminHash + {"Date created" : annotationDateCreated!}>

			<#--  Get annotation history  -->
			<#assign historyList = getFirstHistoryOnly(annotation)!"" />

			<#--  Get last modified date  -->
			<#if historyList?has_content>
				<#local annotationDateLastModified>
					${historyList.date}
				</#local>
			</#if>
			<#--  Add last modified date to admin hash  -->
			<#local adminHash = adminHash + {"Date last modified" : annotationDateLastModified!}>

			<#--  Get annotation remarks  -->
			<#local annotationRemarks>
				<@com.text annotation.AdminInfo.Remarks />
			</#local>
			<#--  Add remarks to admin hash  -->
			<#if annotationRemarks?has_content>
				<#local adminHash = adminHash + {"Administrative Remarks" : annotationRemarks!}>
			</#if>

			<#--  Populate annotation hash  -->
			<#local annotationHash = annotationHash + {"admin" : adminHash}>

			<#--  Get annotation agreement  -->
			<#local annotationAgreement>
				<@com.picklist annotation.EvalInfo.AgreementWithApplicantsSummary/>
			</#local>
			<#--  Add agreement to eval hash  -->
			<#local evalHash = evalHash + {"Agreement with applicant's summary" : annotationAgreement!}>

			<#--  Get annotation data waiver  -->
			<#local annotationDataWaiver>
				<@com.picklist annotation.EvalInfo.DataWaiverAcceptable/>
			</#local>
			<#--  Add data waiver to eval hash  -->
			<#if annotationDataWaiver?has_content>
				<#local evalHash = evalHash + {"Data waiver acceptable" : annotationDataWaiver!}>
			</#if>

			<#--  Get annotation reliability  -->
			<#local annotationReliability>
				<@com.picklist annotation.EvalInfo.Reliability/>
			</#local>
			<#--  Add reliability to eval hash  -->
			<#if annotationReliability?has_content>
				<#local evalHash = evalHash + {"Reliability" : annotationReliability!}>
			</#if>

			<#--  Get annotation evaluation remarks  -->
			<#local annotationEvalRemarks>
				<@com.text annotation.EvalInfo.Remarks/>
			</#local>
			<#--  Add remarks to eval hash  -->
			<#if annotationEvalRemarks?has_content>
				<#local evalHash = evalHash + {"Evaluation Remarks" : annotationEvalRemarks!}>
			</#if>

			<#--  Get annotation cross reference  -->
			<#local annotationCrossReference>
				<@com.text annotation.EvalInfo.CrossReferenceToOtherStudy/>
			</#local>
			<#--  Add cross reference to eval hash  -->
			<#if annotationCrossReference?has_content>
				<#local evalHash = evalHash + {"Cross reference" : annotationCrossReference!}>
			</#if>

			<#--  Get annotation attached evaluation  -->
			<#local annotationAttachedEvaluation = "" />

			<#list annotation.AttachedRegulatoryAuthoritiesEvaluation.Evaluation as attachment>
				<#if attachment?has_content>
					<#local attachmentKey = iuclid.getMetadataForAttachment(attachment) />

					<#if attachmentKey?has_content>
						<#local annotationAttachedEvaluation = annotationAttachedEvaluation + "${attachmentKey.filename}" />
					</#if>

					<#if attachment?has_next><?linebreak?></#if>
				</#if>
			</#list>
			<#--  Add attached evaluation to eval hash  -->
			<#if annotationAttachedEvaluation?has_content>
				<#local evalHash = evalHash + {"Attached evaluation" : annotationAttachedEvaluation!}>
			</#if>

			<#--  Populate annotation hash with eval data  -->
			<#local annotationHash = annotationHash + {"evaluation" : evalHash}>

			<#--  Get annotation conclusions  -->
			<#local annotationConclusions>
				<@com.text annotation.EvalInfo.Conclusions/>
			</#local>
			<#--  Populate annotation hash with conclusions  -->
			<#local annotationHash = annotationHash + {"conclusions" : annotationConclusions!}>

			<#--  Get annotation executive summary  -->
			<#local annotationExecutiveSummary>
				<@com.text annotation.EvalInfo.ExecutiveSummary />
			</#local>
			<#--  Populate annotation hash with executive summary  -->
			<#local annotationHash = annotationHash + {"executiveSummary" : annotationExecutiveSummary!}>

			<#--  Store annotation data in list of annotations  -->
			<#local annotationsList = annotationsList + [annotationHash] />
		</#if>
	</#list>

	<#--  Return list of annotations  -->
	<#return annotationsList />
</#function>

<#macro annotationAttachedEvaluationName annotation>
	<#if annotation?has_content>
		<#list annotation.AttachedRegulatoryAuthoritiesEvaluation.Evaluation as attachments>
			<#if attachments?has_content>
				<#assign attachment = iuclid.getMetadataForAttachment(attachments) />
				
				<#if attachment?has_content>			
					<para>${attachment.filename}</para>

					<para>(size: ${attachment.size} file type: ${attachment.mediaType})</para>

					<#if attachment.remarks?has_content>
						<emphasis role="bold">Remarks for attached Evaluation:</emphasis> ${attachment.remarks}
					</#if>
				</#if>

				<#if attachments_has_next??><?linebreak?></#if>
			</#if>
		</#list>
	</#if>
</#macro>

<#--  The "getDateCreated" function retrieves the creation date of the provided document  -->
<#function getDateCreated _subject>
	<#--  Get the history list for the provided document key  -->
	<#local historyList = iuclid.getHistoryForDocumentKey(_subject.documentKey) />

	<#-- Extract "date" property from history and store it in "dateCreated" -->
	<#if historyList?has_content>
		<#list historyList as history>
			<#if history?has_content>
				<#local dateCreated>${history.date}</#local>
			<#else/>
				<#local dateCreated = "" />
			</#if>
		</#list>
	<#else>
		<#local dateCreated = "" />
	</#if>

	<#return dateCreated />
</#function>

<#function getFirstHistoryOnly _subject>
	<#local historyList = iuclid.getHistoryForDocumentKey(_subject.documentKey) />
          
	<#if !(historyList)?has_content>
		<#return [] />
	</#if>
	
	<#if historyList?has_content>                 
		<#list historyList as history>          
			<#if !(history)?has_content>
				<#return [] />          
			<#else/>
				<#return historyList[0] />                                             
			</#if>
		</#list>
	</#if>
</#function>

<#function getSummaryRichTextSection summary paths role=''>

	<#-- initialise output -->
	<#local pathValue = ''/>

	<#-- iterate over possible paths and create full path when found -->
	<#local pathObject = studyandsummaryCom.getObjectFromPathOptions(summary, paths)/>

	<#-- print path if found and has content-->
	<#if pathObject?has_content>
		<#local pathValue><para><para role="${role}" style="background-color:#f7f7f7"><@com.richText pathObject/></para></para></#local>
	</#if>

	<#return pathValue/>

</#function>

<#-- NOTE: DEPRECATED -->
<#function getDocCategory document>

	<#-- list needed cause some might belong to different categories "above ground'MAYBE TO BE CHANGED?-->
	<#local docCategories = []/>

	<#if document?has_content>
		<#-- if document is list, get the first one to identify category -->
		<#if document?is_sequence>
			<#local document = document[0]/>
		</#if>
		

		<#list _docCategoryMap as category, docNames>
			<#if docNames?seq_contains(document.documentSubType)>
				<#local docCategories = docCategories + [category]/>
			</#if>
		</#list>
	</#if>

	<#return docCategories/>

</#function>

<#-- printSummaryVersion prints the available version of a summary.

	Description: In April2023 EU PPP summaries (mostly Ecotox, some Fate and Tox) have been changed for their harmonised versions. 
	To ensure backwards compatibility, code will be kept to print the old summaries, 
    if they exist. Therefore, for each summary type there is a condition whereby:
        - if the new summary exists, it is printed using the macro in AppendixE
        - else, if the old summary exists, it is printed using the macro in the corresponding common module
		- else, a text message is printed saying there is no summary available

    If both new and old summaries exist, only the new version will be printed - but this situation should not happen. 
	NOTE: this could be changed to printing both summaries, if needed.
	
	New and old could be empty, for cases where a summary has been totally split into different ones (such as ToxicityTerrestrialArthropods_EU_PPP)

	Inputs:
	- new: string or list with new document type(s) and subtype(s); it can be empty 
			e.g. 'ENDPOINT_SUMMARY.ToxicityToBirds' or ['ENDPOINT_SUMMARY.ToxicityToBirds', 'ENDPOINT_SUMMARY.ToxicityToBees']
	- old: string or list with old document type(s) and subtype(s); it can be empty
			e.g. 'ENDPOINT_SUMMARY.ToxicityBirds_EU_PPP' or ['ENDPOINT_SUMMARY.ToxicityBirds_EU_PPP', 'ENDPOINT_SUMMARY.ToxicityToTerrestrialArthropods_EU_PPP']
	- merge: if true, summaries are condensed into one summary (each common section will be the merge across summaries)
-->
<#macro printSummaryVersion subject new old merge=false>
    
	<#if new?has_content && containsDoc(subject, new)>
		
	   <#-- call the macro in this ftl
	   		NOTE: the document type(s) need to be removed (function 'removeTypeFromDocuments')
		-->
	   <@PPPsummary subject=subject docSubTypes=removeTypeFromDocuments(new) merge=merge/>
	
	<#elseif old?has_content && containsDoc(subject, old)>

		<#-- check that global variable with section name exists -->
		<#if _section?? && _section=="Ecotox" && keyEcotox??>
			<#-- call the macro in the corresponding ftl, based on section variable
				NOTE: the document type(s) need to be removed (function 'removeTypeFromDocuments')
			-->
			<@keyEcotox.ecotoxPPPsummary subject=subject docSubTypes=removeTypeFromDocuments(old) merge=merge/>
		<#else>
			<@PPPsummary subject=subject docSubTypes=removeTypeFromDocuments(old) merge=merge/>
		</#if>

	
	<#else>
		<#-- if both new and old are empty, print message -->
		<#if new?has_content && old?has_content>
			<para><@com.emptyLine/><emphasis role="HEAD-WoutNo">Summary</emphasis></para>
			<@com.emptyLine/>
			<para>No summary information available for this section.</para>
		</#if>
	</#if>

</#macro>

<#-- removeTypeFromDocuments removes the document type from the a list of document types and subtypes

	Inputs:
	- docList: string or list of strings containing document type and subtype e.g. ['ENDPOINT_SUMMARY.ToxicityToBirds']

	Returns:
	- docListNoType: list of strings containing document subtypes only e.g. ['ToxicityToBirds']
-->
<#function removeTypeFromDocuments docList>

	<#-- convert to sequence -->
	<#if !docList?is_sequence>
		<#local docList = [docList]/>
	</#if>

	<#-- create new sequence with type removed -->
	<#local docListNoType = []/>
	<#list docList as doc>
        <#local docListNoType = docListNoType + [doc?split('.')[1]]>
    </#list>

	<#return docListNoType/>

</#function>

